(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    405948,       8208]
NotebookOptionsPosition[    396880,       8071]
NotebookOutlinePosition[    397440,       8092]
CellTagsIndexPosition[    397397,       8089]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2f3ecb44-8c1c-41fe-b989-801d605010f9"],

Cell["Chapter 7, Section 7.8", "Section",ExpressionUUID->"7fef9d84-149e-45a0-8a86-b4329eb70594"],

Cell[TextData[{
 "First we define a function ",
 StyleBox["Brouwer", "Input"],
 " that implements the Brouwer & van Woerkom secular solution for the planets \
(except Pluto) and returns the values of ",
 StyleBox["h",
  FontSlant->"Italic"],
 ", ",
 StyleBox["k",
  FontSlant->"Italic"],
 " ,",
 StyleBox["e",
  FontSlant->"Italic"],
 ", \[CurlyPi], ",
 StyleBox["p",
  FontSlant->"Italic"],
 ", ",
 StyleBox["q",
  FontSlant->"Italic"],
 ", ",
 StyleBox["I",
  FontSlant->"Italic"],
 ", \[CapitalOmega] for a given year, ",
 StyleBox["t",
  FontSlant->"Italic"],
 ".  Note that Brouwer does not derive a secular theory, it merely implements \
the published solution of Brouwer & van Woerkom."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4fb76925-797b-44f6-84c0-87a325965505"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Brouwer", "[", "t_", "]"}], " ", ":=", "\n", 
   RowBox[{"Module", "[", "\n", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
         "5.46326", ",", " ", "7.34474", ",", " ", "17.32832", ",", " ", 
          "18.00233", ",", " ", "4.29591", ",", "\n", "       ", "27.77406", 
          ",", " ", "2.71931", ",", " ", "0.63332", ",", " ", 
          RowBox[{"-", "19.18225"}], ",", " ", "51.25222"}], "}"}]}], ",", 
       "\n", "  ", 
       RowBox[{"\[Beta]", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
         "92.182", ",", " ", "196.881", ",", " ", "335.224", ",", " ", 
          "317.948", ",", " ", "29.550", ",", "\n", "          ", "125.120", 
          ",", " ", "131.944", ",", " ", "69.021", ",", " ", "293.979", ",", 
          " ", "220.691"}], "}"}]}], ",", "\n", "  ", 
       RowBox[{"f", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5.21054"}], ",", " ", 
          RowBox[{"-", "6.57080"}], ",", " ", 
          RowBox[{"-", "18.74359"}], ",", " ", 
          RowBox[{"-", "17.63331"}], ",", " ", "\n", "       ", "0.00000", 
          ",", " ", 
          RowBox[{"-", "25.73355"}], ",", " ", 
          RowBox[{"-", "2.90266"}], ",", " ", 
          RowBox[{"-", "0.67752"}]}], "}"}]}], ",", "\n", "  ", 
       RowBox[{"\[Gamma]", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
         "19.433", ",", " ", "318.057", ",", " ", "255.031", ",", " ", 
          "296.541", ",", "\n", "           ", "107.102", ",", " ", "127.367",
           ",", " ", "315.063", ",", " ", "202.293"}], "}"}]}], ",", "\n", 
       "  ", 
       RowBox[{"eij", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0.17454", ",", " ", "0.00610", ",", " ", "0.00392", ",", " ", 
            "0.00064", ",", " ", 
            RowBox[{"-", "0.00001"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00001"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.02550"}], ",", " ", "0.02094", ",", " ", 
            "0.01634", ",", " ", "0.00290", ",", " ", 
            RowBox[{"-", "0.00001"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00001"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{"0.00154", ",", " ", 
            RowBox[{"-", "0.01255"}], ",", " ", "0.01043", ",", " ", 
            "0.02972", ",", " ", "0.0", ",", "\n", "               ", 
            RowBox[{"-", "0.00001"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.00169"}], ",", " ", "0.01483", ",", " ", 
            RowBox[{"-", "0.01483"}], ",", " ", "0.07237", ",", " ", "0.0", 
            ",", "\n", "               ", 
            RowBox[{"-", "0.00001"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.03571", ",", " ", "0.01909", ",", " ", "0.01834", ",", " ", 
            "0.01861", ",", " ", "0.04482", ",", "\n", "               ", 
            "0.03291", ",", " ", 
            RowBox[{"-", "0.03188"}], ",", " ", "0.00063"}], "}"}], ",", "\n",
           "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.00096", ",", " ", "0.00006", ",", " ", "0.00283", ",", " ", 
            "0.01502", ",", " ", 
            RowBox[{"-", "0.01535"}], ",", "\n", "               ", "0.04863",
             ",", " ", 
            RowBox[{"-", "0.00248"}], ",", " ", 
            RowBox[{"-", "0.00011"}]}], "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.00043", ",", " ", "0.00042", ",", " ", "0.00044", ",", " ", 
            "0.00059", ",", " ", "0.00147", ",", "\n", "               ", 
            "0.00148", ",", " ", "0.03043", ",", " ", 
            RowBox[{"-", "0.00323"}]}], "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.00001", ",", " ", "0.00001", ",", " ", "0.00001", ",", " ", 
            "0.00002", ",", " ", "0.00005", ",", "\n", "               ", 
            "0.00006", ",", " ", "0.00143", ",", " ", "0.00938"}], "}"}], ",",
           "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.00021"}], ",", " ", 
            RowBox[{"-", "0.00011"}], ",", " ", 
            RowBox[{"-", "0.00012"}], ",", " ", 
            RowBox[{"-", "0.00020"}], ",", " ", 
            RowBox[{"-", "0.00016"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00049"}], ",", " ", "0.00020", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.00010", ",", " ", "0.00004", ",", " ", "0.00015", ",", " ", 
            "0.00064", ",", " ", 
            RowBox[{"-", "0.00054"}], ",", "\n", "               ", "0.00202",
             ",", " ", 
            RowBox[{"-", "0.00016"}], ",", " ", "0.0"}], "}"}]}], "}"}]}], 
       ",", "\n", "   ", 
       RowBox[{"iij", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0.12449", ",", " ", "0.01178", ",", " ", "0.00849", ",", " ", 
            "0.00180", ",", " ", 
            RowBox[{"-", "0.00002"}], ",", " ", "\n", "               ", 
            RowBox[{"-", "0.00003"}], ",", " ", "0.00002", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.03545"}], ",", " ", "0.01004", ",", " ", 
            "0.00810", ",", " ", "0.00180", ",", " ", 
            RowBox[{"-", "0.00001"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00002"}], ",", " ", "0.00001", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{"0.00409", ",", " ", 
            RowBox[{"-", "0.02680"}], ",", " ", "0.02448", ",", " ", 
            RowBox[{"-", "0.03589"}], ",", " ", "0.0", ",", "\n", 
            "               ", "0.0", ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{"0.00116", ",", " ", 
            RowBox[{"-", "0.00685"}], ",", " ", "0.00453", ",", " ", 
            "0.05025", ",", " ", "0.0", ",", "\n", "               ", 
            RowBox[{"-", "0.00002"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
           "0.02757", ",", " ", "0.02757", ",", " ", "0.02757", ",", " ", 
            "0.02757", ",", " ", "0.02757", ",", "\n", "               ", 
            "0.02757", ",", " ", "0.02757", ",", " ", "0.02757"}], "}"}], ",",
           "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
           "0.00028", ",", " ", "0.00012", ",", " ", "0.00281", ",", " ", 
            "0.00965", ",", " ", 
            RowBox[{"-", "0.00631"}], ",", "\n", "               ", "0.01572",
             ",", " ", 
            RowBox[{"-", "0.00069"}], ",", " ", 
            RowBox[{"-", "0.00008"}]}], "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.00332"}], ",", " ", 
            RowBox[{"-", "0.00192"}], ",", " ", 
            RowBox[{"-", "0.00173"}], ",", " ", 
            RowBox[{"-", "0.00126"}], ",", " ", 
            RowBox[{"-", "0.00096"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00078"}], ",", " ", "0.01760", ",", " ", 
            RowBox[{"-", "0.00207"}]}], "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.00145"}], ",", " ", 
            RowBox[{"-", "0.00132"}], ",", " ", 
            RowBox[{"-", "0.00130"}], ",", " ", 
            RowBox[{"-", "0.00123"}], ",", " ", 
            RowBox[{"-", "0.00117"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00113"}], ",", " ", "0.00110", ",", " ", 
            "0.01175"}], "}"}]}], "}"}]}], ",", "\n", "   ", "time"}], "\n", 
      " ", "}"}], ",", "\n", " ", 
     RowBox[{
      RowBox[{"tg", " ", "=", " ", "g"}], ";", " ", 
      RowBox[{"tf", " ", "=", " ", "f"}], ";", " ", 
      RowBox[{"tb", " ", "=", " ", "\[Beta]"}], ";", " ", 
      RowBox[{"tga", " ", "=", " ", "\[Gamma]"}], ";", "\n", " ", 
      RowBox[{"eji", " ", "=", " ", 
       RowBox[{"Transpose", "[", "eij", "]"}]}], ";", "\n", " ", 
      RowBox[{"iji", " ", "=", " ", 
       RowBox[{"Transpose", "[", "iij", "]"}]}], ";", "\n", " ", 
      RowBox[{"time", " ", "=", " ", 
       RowBox[{"t", "-", "1900."}]}], ";", "\n", " ", 
      RowBox[{"h", " ", "=", " ", 
       RowBox[{"eji", ".", 
        RowBox[{"(", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"g", "*", 
               RowBox[{"time", "/", "3600."}]}], " ", "+", " ", "\[Beta]"}], 
             ")"}], " ", "Degree"}], "]"}], "]"}], ")"}]}]}], ";", "\n", " ", 
      
      RowBox[{"k", " ", "=", " ", 
       RowBox[{"eji", ".", 
        RowBox[{"(", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"g", "*", 
               RowBox[{"time", "/", "3600."}]}], " ", "+", " ", "\[Beta]"}], 
             ")"}], " ", "Degree"}], "]"}], "]"}], ")"}]}]}], ";", "\n", " ", 
      
      RowBox[{"e", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "*", 
            RowBox[{"h", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "*", 
            RowBox[{"k", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "8"}], "}"}]}], "]"}]}], ";", "\n", " ", 
      RowBox[{"cp", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"k", ",", "h"}], "]"}], "/", "Degree"}], "]"}]}], ";", "\n",
       " ", 
      RowBox[{"p", " ", "=", " ", 
       RowBox[{"iji", ".", 
        RowBox[{"(", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"f", "*", 
               RowBox[{"time", "/", "3600."}]}], " ", "+", " ", "\[Gamma]"}], 
             ")"}], " ", "Degree"}], "]"}], "]"}], ")"}]}]}], ";", "\n", " ", 
      
      RowBox[{"q", " ", "=", " ", 
       RowBox[{"iji", ".", 
        RowBox[{"(", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"f", "*", 
               RowBox[{"time", "/", "3600."}]}], " ", "+", " ", "\[Gamma]"}], 
             ")"}], " ", "Degree"}], "]"}], "]"}], ")"}]}]}], ";", "\n", " ", 
      
      RowBox[{"i", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"ArcSin", "[", "\n", "       ", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "*", 
               RowBox[{"p", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], " ", "+", " ", 
              RowBox[{
               RowBox[{"q", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "*", 
               RowBox[{"q", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], "]"}], "/", 
           "Degree"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "8"}], "}"}]}], "]"}]}], ";", "\n", " ", 
      RowBox[{"om", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"q", ",", "p"}], "]"}], "/", "Degree"}], "]"}]}], ";", "\n",
       " ", 
      RowBox[{"{", 
       RowBox[{
       "h", ",", "k", ",", "e", ",", "cp", ",", "p", ",", "q", ",", "i", ",", 
        "om"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869218639253874*^9, 3.869218639260439*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"4952c245-cd75-44d2-8752-1611fb8ac6aa"],

Cell[TextData[{
 "Set up a list, ",
 StyleBox["time", "Input"],
 ", containing the times we are interested in.  The units here will be in \
millions of years."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1c9bd0f6-1df9-4a93-a327-d87924ce016d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"ttt", ",", 
     RowBox[{"{", 
      RowBox[{"ttt", ",", 
       RowBox[{"-", "5"}], ",", "5", ",", "0.01"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8692186553090153`*^9, 3.869218655317347*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"45136d95-4b7b-4853-99eb-4074ac28b597"],

Cell[TextData[{
 "Create a list, ",
 StyleBox["ecdat", "Input"],
 ", of the eccentricity values."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"de3ed58c-f7e5-48cd-a283-896452855a5f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ecdat", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Brouwer", "[", "tt", "]"}], "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"tt", ",", 
       RowBox[{"-", "5000000"}], ",", "5000000", ",", "10000"}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869218669545835*^9, 3.8692186695532722`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"78e086f6-3f1c-4d30-8c87-faca00eedacf"],

Cell[TextData[{
 "Create a list, ",
 StyleBox["idat", "Input"],
 ", of the inclination values."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"40569932-731f-420c-a31c-bd55aa932ef4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"idat", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Brouwer", "[", "tt", "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"tt", ",", 
       RowBox[{"-", "5000000"}], ",", "5000000", ",", "10000"}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869218684082272*^9, 3.8692186840879593`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"9e24b7d0-0f99-43cc-b928-458f3c42f82c"],

Cell["Isolate the eccentricities of the planets.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d433d43d-4f35-4582-bac3-f98b002bc479"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "emerc", ",", "evenu", ",", "eeart", ",", "emars", ",", "ejupi", ",", 
     "esatu", ",", "euran", ",", "enept"}], "}"}], " ", "=", " ", 
   RowBox[{"Transpose", "[", "ecdat", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.86921882011734*^9, 3.869218820122991*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"065ec682-f012-44cb-ad4e-73d35f5a95b3"],

Cell["Isolate the inclinations of the planets.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c728e08a-5abd-4ee1-bc19-a43ab3a03ea0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "imerc", ",", "ivenu", ",", "ieart", ",", "imars", ",", "ijupi", ",", 
     "isatu", ",", "iuran", ",", "inept"}], "}"}], "=", 
   RowBox[{"Transpose", "[", "idat", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869218912981771*^9, 3.869218915597187*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"df3a360f-5ef5-454a-bb17-365452cb1290"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<Time (My)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eylabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
StyleBox[\"e\", \"TI\"], TraditionalForm], \"errors\" -> {}, \"input\" -> \"e\
\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iylabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
StyleBox[\"I\", \"TI\"], \" \", 
RowBox[{\"(\", \"deg.\", \")\"}]}], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"I\\\\,\\\\rm{(deg.)}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.869219273394857*^9, 3.8692192885155163`*^9}, {
  3.869219322836817*^9, 3.8692193269608107`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"6f296be4-33f0-4a68-939b-c0bcaf038739"],

Cell["Plot the eccentricity of Mercury.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e63e2045-f9b4-43c9-b2db-38630e3aa82f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pe1", " ", "=", " ", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "emerc"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.25"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "eylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.1", ",", "0.15", ",", "0.2", ",", "0.25"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deline1", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0.1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.25"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pe1", ",", "deline1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869219809285471*^9, 3.869219835235938*^9}, {
  3.869219897232533*^9, 3.869220016031439*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"4dcabdab-5b72-4e0f-9f98-7764cf40fc1d"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923VcVM3XAHA6l2XD7m4MLBRhxsAAUfQRWxQssEAx0BcFURQbOxBB7IBH
LFCBGbYXWEJEwkIEQVCkO959ljk//vGzn5XLvfOdO+ecif5unos36mhpaf3S
1dL679+On040fPy0wX3cElHdsNXnRLVCusBq1KvPWYno96LYPoFlQjqhSMvb
SiBC3w90iprzXUi/X2lWcmaJUPYdLxuTbCF9T0rm2Z8WIVXKfz9Cuq1q+AmP
XBES1/53QSF9tHrndDRIjP672qJYIZVFmr4cvE6M1BdTX1FILz3Omqq4J0Z3
/7vcHSHtWbAtHU+SoBvX//sR0jtnJhRPNZYi9c2pLyikM1bFupmXStF/V+sT
KKQ1GaY2nR/J0P/9d3sHhPRwp54Os3vL0c7/LuclpC+cVkmD3OVok+ZHSE+5
/HuGI5Gj1ZoLCmldbX6o+RgFWqy5QSF19UwYH3hXgeZqHlhIqxydJ//sqkSa
y9mo28fFfnnEESUar/kR0riJAxVhXZPQcM0FhfRWmi933Ock1Fdzg0I606pg
lG1EMtLcXichnb6y/OqvWSlIczkTIY3yPLS9PCQFdXgI6UvPqWjrvynMQ0CX
mc/uOzwhhXkIaOvQGEfTrynMQ0BHpPzMfSJQMQ8BvWRUf8Z/pYp5CGjwQwOX
T1dVzENAVUmc1U4fVcxDQA/YvyrdMyyVeQjo8bcvOi3Ymco8BDR2SP2N3bdS
mYeAHom/lbbkSirzENCjx2b1+TgzlXkIaO+ASZuTM1XMQ0B/vQxp67dTxTwE
NMknOajRQsU8BHSKY8Wi/+uuYh4C6msYkMkzUzEPAd39yaf31eIU5iGgoVRV
2foqhXkI6MLHOeFOu1KYh4BezXfJFvRJYR4C2mZhKDePTWYeAhrjXVJwqSd4
COgHh4tEa2kS8xDQEs81Xx+FKJmHgH5eGHw1z1TJPPjUeu/OgQ6JCubBp53W
Dn32+IaCefDpmeFzblgvUTAPPqVjdxyRlsiZh/r7ReMjWzbIkab5RHzaijMP
7M6TMQ8+NZhXeW7FOhnzUH/Or6p5nSVlHnyqc5n3LX2ElHnwaUuX/OP0jIR5
8GnUSOke2/4S5sGnVydtHBLZLmYefBopH5M0SyBhHnz6umzT07sGEubBp0YB
WbNyJWLmwaffbmoZNG4QMw8+HdV4Z+4SXTHz4NOBgZZDtBUi5sGnlrXSVSPD
RcyDT3sWaXXdslHEPPj0By/n48lxIubBp5ucKjwf9RMxDz51wvf71duJmAef
pk8ttd4RImIefDqrUr7fLFvEPHiUX3T175H3IubBox+PRXkXPYTxikdvFzhK
Z/jAeMWjR5u9z13dBuMVjx5u9lr78ISIefBoQvbCT5W3RMyDR3lPOMGznoqY
B4/KEl9W2shEzINHrQ60Kt7XipgHjzpEF59NnSdmHjy6I/vBxH9DxMyDRyM9
TDld48BDff0tz33iY8XMg0eru076dOmOmHnwqO+l+k23roEHjz7+UO438x14
8KjBTVroUg0ePNrrVNwpj+ES5sGjx8c2nR3rKmEePLrWOtX0wFkJ8+BR00WN
sc2JEubBo3dM6hI2cqTMg0efcc+vanGUMg8etQ0dk7lnv5R58Gi82/pR005J
Wfub0/HJ4Z4Sfylrb3OquD3nyUj19x3ta069R7ZduyaVsvY0p+WRM8+1CmWs
/cwp4eoVH3GVsfYypw3b1ux/ck6GNM3tZU4DD2/ZZhIiY+1hTp+GPzuwIUbG
nt+cFufdsFj4R8ae15xGjXKardVPjjScfczpPN68aTenydnzmNMpA4pz7UbK
WX/iUsPrgX+XmshZ/+HSTYser4vuLEea7pLCpRuenSr5OFPO+geXvuu1Kuys
t5z1By7duvu64YJAOQrWPDCXJhe8utvkKmfeXHp/nuzxDyuIR1x6bt6DY3oT
5cyTS7/Yvt6XOV2ObDU3yKUeA6bd3mAvZ15cOn7wOZ6/pZz5cGnBuIBfVQ0y
5sGlN6+EfbfMljEPM+pw3GrqF/X40uFhRk9siShOKpYxDzO6e3z0v+G/YLwx
oxz/4dMHiMHDjHZ7+LYOnwEPM/riSV5zrh94mNHtb9++mnYFPMxo2khvq7fx
4GFGm7Jf+5V8Ag8zWmrxxi4vS8Y8zKihsV2YKEPGPMzosPkFvL+/ZcyDQwcY
fDT16gYeHGrr9ntNviN4cGiy4yrX5l3gwaEWnE9eTcfBg0MV3U4F58SDB4dO
7zf6aEg3BfPg0Gm/nkxackzBPDh04GOTP/OrIB/gUK+d9Zk+45XMg0NDfebd
CF+uZB4c6n5lX29VkJJ5cOjOszY/1sogfnDoA9OKQtseSczDlGbd+3LF2juJ
eZhScb7dqk2vkpiHKX0Y9nVHSVMS8zClA5KHPZUtTGYepjRfkNFc9yiZeZjS
wbw7pu76KczDlO454XBztlUK8zClruNCBuRbQvw0pW3hMxve9IJ4aUpts73K
fM1SmIcpbX04/6xbH8hPTOnle7/8jJ0gHzGhJ/ffOfN9B+QfJrTHk0fX3bxS
mIcJ3d7t7OP9m1KYhwn9e7+X+PySFOZhQrPu36vQsU9hHibULeTut5aRKczD
hJrfSBzxVZXMPEyoR+1Wrs7cZOZhQo1ueJ6ZLEliHiY0eFHu4bebIP8yobai
XQuxXRLzMKEl46m22/Ak5mFCY3i9mjd/VzIPY7rudvCnFh8l8zCmtY2nl4e2
KpiHMe29ipdff1zBPIxpj4zVwzZ2VzAPY8p7xz2C/eTMw5guuKMbXB8L74cx
HXBpoVN7jZR5GNOFZ92dkpZKmYcxzb2Z7+HfDuOzMZ1XcnmgKk3CPIxpuEgS
mOIvYR7G1Cl9marBWMI8jKhtzBnjXj5i5mFE593e2bPus4h5GFFu6p3rnZ0h
nhnR+/W7q24qEpmH+vszCS8fDEpkHkbUZmpyca9TlHkY0a43PoaGCyjzMKLx
h+fY+z0mzMOINmP+izHqzx0eRtQlMAeH3SPMw4gKz0/s9XQVYR5GNGod17I5
LYF5GNGdzoszf+snIE3zlRlSxStj7+VO8czDkBKP+wtacuOYhyHVDc7qnXIw
jnkY0jPL/wbdWxzHPAzpuc5ay+avjWMehtS9df/65MdxLL4a0icmr6IU6+OZ
hyHd5zfFbZJdAvMwpNM6GU9NrEpgHoZ0TqWt7lxnwuKjId3zpWSRrvpzh4ch
jXNt9Cu1IczDgJZtIi11QYR5GFBlHzdun+6U5RsG1DkqKMT7PGUeBtQ+cKBx
Ri/wMKCH+2o5+N5JZPmDAW0J+Bm9AYuYhwE9+SrFoqBBxDwMaOaw4vqi25AP
GFAusvLzHgjx34CWlhttWuwB8d6A5g53ChoZJGEeBtR14qS0THV/6/AwoHMv
7Am7uFLKPPTp49/Gfj/MIX7o04deo+N7vYf4oU83TNL98m6PnHnoU4voL82f
9BVIw3Fdn87J3qfT5YGCeejT7euwyHe6knno0/X32xzWxCiZhz4VKhuzaJ2S
eejTFbfSTzq2Q72lTy/ph/mTLlBf6dPJC031A3ZC/q5P/7w+1SVNPX52eOjR
ywYG6TsuJjMPPfpVPlRowElhHnr0xvL1Vg8XwXilR28HfvUYfhrGKz263c+3
bBhJYR56dEfM529bsmC80qOvDFp3nkxOYR569OCTsAEFl1OYhx4tiQhsMVgG
9YoevRsiX1Y7D+oTPdrm65/jsCWFeejRjM27fpWFQz2oR/dtw7HtyhTmoUsP
iw/9qYtJYR66dG7niWcq/y+FeejSaouijHFjU5iHLj07wepGbmYy89Clj6be
/eK2D+KHLvVa8sKrsyCZeejShxf3e1veSmIeujRHRfrcmJ3EPHRptz3L/KrU
7d/hoUun1Pn+rdYBD11avzfh29IGJfPQpYVab7KPEaifdKgr/34nfUcl89Ch
FxbZnHOUKZiHDrUq6zJLjhXMQ4f+DvHRWvgZ4rkO3Rc22T3tmpx56NDZexJO
bVwE+ZUObezt0c26E+RXOrQlqKCHsFrGPNSfY9K7DiqVMQ8dOvKBiVtDvYx5
6NAXc8+uCCqTMQ8dWmrUfnXKPcivdKhD4d/Mo/Yy5qFNb7j1CbZrg3xXm4aV
BXQ/Uwj5rjbVQZkjFDqQX2nTo1ceCsP7ypiHNi3wPFB/fATkV9r0c1xp4tpJ
MuahTW3askU18yC/0qZdTUpUWXsgv9Km/n1zogaFQH6lTbeFDhwoPyFjHtrU
93RVVf5yyK+06cczBtqXx0B+pUXXevZN1h0rYx5adMyewHs6W2XMQ4uamH1Y
EXAf6lMtGhHPMznwWsY8tKj16il3BkXKmIcWXVB79GjfUJiP0VJ73ehaHyFj
Hlr0U/PrPR7vwEOLZsZIzS5EgYcWrdxn9GqeD3ioPxN3bvM08NCiE4ovtlh1
BQ8t6jPr/t2IgTL0UdP+7eSS8YrZ/rOgvdtJmHiSxTEkQ0c17dtOcjNV9226
Q3u2kxuiL9F6RVJkqWm/dlLmvvJQ5xiod9pJv8EbYkc/kqJ8Tfu0Ee7gpb3O
3ZSy9mgj68kQK85uKYufbeRMQMvmVdOl7HnbiGM/Wc0SUymLj22kQqq7YtZP
GH/byNbpa/zbf0hYPtJKhDNCTTn5EtZ/WknU55ymr3KYD2slhb9XtZwNk7D8
opX8uPXpp6ubhPWHVlJu48qxGw/5Qyt50E3y+s0wyBdayOklY3jaQyQsP2gh
r+bocHN7S5hnC+Gf05//sV2MNI97oIUE6Nh0qpRCfGkh4bvd5xTeEiPN5Ya1
kAvPomMrr4qZRwuZ//nSsVGXxcyjmegFRc6ZFgTzfc1EV3xk4dGVYubRTBRK
xRCDvlDfNpOxH1p+zuGJmYf6e73zbT7DxcyjmRx4L+vUMkfMPJrIwr03A10W
wPxiE/k2+GnGg/5i5tFE2qa0fJOUQbxsIl38+/UZ/V3EPJrI1giTrPBqmH9o
Ihts/HW2cMXMo5GMuzjlX343MfNoJF9HHfXncMTMo5HoPii/tGKQmHk0krK8
iuEDd0I93khoQVR9p2Qx82gk2kUPd10XgEcD4dy5cv7E/zwaiMXinlW7+4FH
A7HKmbBri52EeTSQyEf2aaNCJMyjgawfXx4230zKPBrIxVvcdqsAqM8byIeI
+JPnvkqZRz1xtZm26vpseD/qSWxc7BvlB3g/6olZu3OklzvMj9aTMRt/zOf+
kjOPepIbtUD7nbWCedSTG9vXdbq1WcE86kjB7pf5qf/C+F1H+r2LvV4xQsk8
6khm4KQTw+VK5lFHtGP1rw/zhHy+jpxS17ZP6iF/ryNLdmYO0tqYzDxqyXRO
98/XPiYzj1qyysx3Q6ZNCvOoJdcu9n+deB7qoVqimv21TaaA+qeWPFDe43pk
Qb1TS/y9Lo88Uwj1TQ05FWbuGdlDxTxqyLJlkd+tvFTMo4aYnsuz8/qsYh41
xEXyY7+hZSrzqCFVPVGIz4JU5lFDkPvk5ulzU5lHDTn3zHB75LBU5lFN9iRu
mvehScU8qoktvVDrkapiHtVkueP3fm0nYH60mgSu0BaUjVcxj2ryfNso0fZq
qNeqydANM94MTE9hHlUkNGn1YO00yG+qSNjhEe8vp0H9VUU+dfYw3h8M+UsV
6T5pzsWj5inMo4rYv9xrE+wB86VVJK/fzoEz46CerSTO0b4+QWOgfq0kQ/N6
njr1TMk8KsnWYUs4DX2VzKOSePzzaLbZVZhfV4/u9R7e7UMVzKOSGB9cOef6
F5iPqSDXZV14S55AvV9BJijPfT02F/KBChKd6n5EcVXGPCoIOu3fLSJeyjwq
SEbqs+wb6vG1w6OCXC7ccWgOgny3gpTpj38uey9GzzTt/5fc2tz3xwUPMVqu
ae+/RHrKV2+qjhgZadr3L0ne+3DJmkiop8pJ6KVxF4/sFCF3TfuVk1JDcWCX
f0SIp2mvcjJMbjpG1EOEqKZ9/pA9b77mLriZyNrjD4kWHmm1b6Son+b5/5CD
9xbgsy4UpWue9zfpnbH8fqUWRT6a5/tN+nbxejThD2HP85toH3N7NcWAohxN
fyojB4eYVyt5FAV1JChkZcvVBXd6UTRW01/KSJfKGVubhlLWP0oJ0ikc2GcG
Zf2hlIy8ubA5xpkirPEvJT0MzqWemUxRieZyv4j3v98S1jcSdE3j+4ss8l/h
/vUiYZ6/iGPcPtGRQIIaNDdYQiQue84LOBSFax64hGzrkn54zmGKnDQNWEKe
iZxzR1dS5lFCusbElJ9Yksg8iol3TKx7srq9OjyKyYbSwvlnsxKZRzGpUQVd
3tIJPH6SpmuWfvYzweMnOfHl4OtoV/D4SYwWRvW+fhg8isiQ8A8Wkx6LmEcR
mf4+4M1FfTHzKCJF8UO9uqvrK4XGo5DM1YmM1FkoYR6FxDThQMCzCuhfhSS1
7eiRxxulzOMHCblbN3XKHSnz+EHK+6yxas2TMo8fZH/3uf2e95cxjwIiMvmS
uc5DxjwKiH5e6du3/8qYRwHR6iG8XFUkYx7fyYSMpeF3BsqZx3cifV4dd/mm
nHl8J4ED9358Y6NgHvnE5h/jX8eyFcwjn4xyG7c5RF2PdXjkk84/H2s/Ww3z
V/lktunN3dJ/lGidpv2/kUIt4tB/nRI907T3V+JgnmYkOKhk7fuVRJwb7HMq
DN73L+SIRa7n9ZdK1p8/k5F3y6uTXylRP017fSYR09aess1SIn9N+3wic7wm
H+veJ4m1Rx4JGx7bvWxDEnv+PDI3MCD9VlASCtY8by5xbtbPmbcpCVVoni+H
HAkNdeabJbHnySFRTVG+Pur6o6M/ZZOfWunzn55V329Hwk70XZ99c/dWP5+m
v3wkEZPN7R3clKx/ZJGTx/zXWtsoWX/IIps2rBlo0V19vxr/D8RpX5egx3z1
82kul0lmTVxsG2umZL6Z5G1JdP/2ZgXzfE+uOHoHnpQoUIXGL4N8ndy36cZq
BcIarwxSv21EzKwmOfNJJ5OLo/TuEjnzSCczG31eP1ePh1TT/qmksX1tQu4b
OVqnaW8VsV/eeoGq/39H+6aQmpIr832fy1l7JpG5E8Oeip+pr69pPyWZWLcm
Y89rOcKa9lKQP+7lwuUi9d/TtI+cZB5YNdA9Wc7aQ0pMLryZ6fJKzp5fQgb4
jshtDVX/Pc3ziknwt8K3/R6r/57m+RLJyNNH737Mg+eh5Eq949yKsQp2/wlk
3BeeU2mA+vk19xtHet23PK2MVCB/zf29IRt9HOb6JCvY/cQQzu6A4TtKFezv
vyQ7TT1n5ndR91fNgB9NxhT7eJgvU/torh9FbmaOnlJ1WMmu94h82nXqfNQF
8LtLVvBeDLr8SP37moLpFrkaGK/qnK7+rPn+EnHKdf1xslMS+3yUvDpdt/Sn
C8wnamkJ5YqFxvv/9z3612K2zbmt6s+dNb+PtLcXxjb9kwTXR6HJH76tm5cE
fx+9/03Kw92S4P4Q/XX5jf4++P9RaE+t45Shq5Pg+dAQm5zRRkPh91+icBx9
amu5EtoHzXHYW1adou6/He2HfoV22ZUhU0L7olMtDibGEUpof0SjXra9sVeC
D+oZNPF0jwIF+CGTP7PLSv7z6fBFN0e5pnvMh/aXoJG/7vtsGamA/oEKnBZ/
tvj+v/6DxooutNRsVffPjv6FjlR96X6gWAb9D709/XmkzTYY/5LQhP5/H3mo
6zvWfxFd6ra9LkmK/Dv6N7o36X2Vu4sU+j9adujT/BmFEM/TUYXIeUi/HRJ4
f9Ayq07+L8wlyKnj/ULdi19H2H4Uw/uHDvUyc227CPXCe+RTVvt59WgxvL9o
/BqjrA8vRSi/4/1Gtstq1p4aLYL3H0lSH549Hp8I4wM61sQ76bAvEcYPpFTZ
ceynqeN9x/iCAmYdfcTTS4TxB/3ay/3lkUJhfEJ/TDaH1J2B+JiDsvOm6AZs
pjC+ofvhT4a/WEZZ++Ui7alF2dbWEK/zkLeXtKgzB+J7HnIr2717UwCB8RVV
iiuHz8lPQGM7xl80wDgjLOZJAozPaMekK1mDixJg/EY9Qn8iq0UExnd088WJ
nxYiwtr/K6qfWfQ2ooFAfEAS6xpjJwHE83z0sNMy26TZ8Dz56Fa/4e4FARQ9
7Ig/aGP/3JitLynEJ6RTfn2FeSqF+IUW1Yzt1vUjhfiGlJdGuEzhJzK/7+he
84nJ768nQnxEbQ0mfmfniiB+os4+jg7FdSKIr4jTnmDxba8YWXXEX7TyRnJs
ZqoY4jO6nDpnWcwkCcRvdGzZOJXjs//Fd1Rxtdfg0cOkEP/RnGNxqz5ckLL2
K0SioBehy35KIX9AwxcPbd28FNYDitDRwUMy9nBhPC1CZU9H6AjK5KhbR36C
jkU17nhEFJC/oJGjbk5YvkYJ+Q06VBfmJlfHU5b/oDe7Njg8a4P4XIyOP0y7
XLk8CfInhJ79PjszFsarEjSn6o8itnsy5F/I9Kz7nltbkplHCeqn+66PTVwy
5G8oTVDsMH4a1E+/0LqeC6ZPy06B/A81edouy92oYh6/0G2trKSVMhXkj2h+
qd7TmdkqyC/R44rQA5feqCD/RCZJLsdbb6mYRxl6dQ3reJ5TQf6KDj98+ghd
VUF+i4rs5lmIH6og/0ULh3Qb1jtSBfkxslz19JlfnAryZ3Sgdto2x48qyK9R
3vH6F5e+qyD/Rk8zgu5K3qsgP0cb7p+vmB2oYh7lKNJu+9fQuhTI71FQ1sIr
C1dBPVWOXlt8S/78PhnqA7STK0lL9klmHn/RAJniXT/HZKgv0OrJY9rseyZD
/YHcw8N7XPyYBPUJeu1cY/RAnd8s6ahfkEn1mojAEUnIt6O+QfLVRkNfqsdz
Vv+gEp1F017NVkJ9hAZtyQjdcAbyvQo0WPCpMUosZ89fiT6PLG/07g75YSXy
frfOvfoZ9M9KdP30uW4Wl2ToZkf9huYsDuwq8pchSUd9h3qdvvXx1WxYX65E
fiurT/MrYL9AFSrvys92OSZl/lWo+XqM4N5gKWu/KtTN54eNa6oE6k/UefmD
fNFyCdSnqPDetj2Hc2F+pwoZSK8PyfQXI05HfYs2rfWWJG8Rowkd9S/yd/zc
UBoB80fVKHu8S8mkEphfqkY1RlPym2qgvqtGgiHnWgvTxKw/VaPbb7jbQoNh
/qoGLb2+bP2ZNTC/VYNWZunP/e0oZh41yP3UgDO9p4iZRw3KK3af4dIV9q/V
IOmIllvLzMQwf4Csa+PDGy3EzKMGTbbf3+odBPVFLXqnV/LuSA3MF9Uiv4Yz
n3KHwPxeLara9eNuQw8J86hFPVHm+LQ/YuZRi7Z1/nf1aQrzVbXofMJu7ok4
McyfIAc3I4dl6vGtw6MOFeolkwZ1/OvwqEP9Wst1lvyC+FeHZkvsxNlm4FGH
lpRpDfvgKIH5HTTQxDPB85GEedSjclx71LpMwjzq0Z3MkwfbGyUwf4QO3bT/
8KJIAvNLSO957wmzYiXMox512Xo9cXoIjLf1SHinasDtJxDPG9DLlxOr7NJh
/G1ApTNPOBMtKfNoQE/DHn5qspQyjwZ0YM3T6O7LYb9UA1rxtj7W8pQU5teQ
39b3fV8kS5lHA5qPB+ZMr4fxuhFdmildVqsL8+uNaPeggXfHFUphfg8h4aAN
S59ImUcj8hp9au/aECnzaETO1DO4JgH2wzSirQhNlDTC+9GE+p5oTJ8zDuq5
JmTSPeHj2Oky5tGExhs+cw22gfqvCflNyQs8tBjm35uQ0CAq7/gOyJeakCvv
dn7kPhnzaEan3niXvV8hYx7NyNPSN3aIOcx3NyODYTufrvsohflX1P+ftG6f
1PVoh0czsp2j1f5UW8Y8mlFFjv6ZrSNhvr0FBUyy7uc6Rgbzvyi1bW54i7GM
ebSgi6Spk201eLSgj643Ol2uBY8W1PtB3783G8GjBZ13dPf8UwEeLehexemC
AzLwaEV7F846mhAK6+WtaLrT1Db0FDxakcv7uRk3CsCjFfWmNzpLBsF41Yqu
HpvKm7gIxqtW1H9luvOtxbCe0IaWvHceaLsCPNpQ5fHs/Ngj4NGG5q1Mi0sQ
gUcbCr7QPMuLA/tN2pCN0Vl/5Qyor9oQ139S5TcPOfNoR9NnL261j5Yzj3ZU
ZR19M7yLAtYf0OyjpxYbHFfA+gTy4f5aePyvgnm0o+YeGzeWjVUyj3b0qa6L
L3cz1OdaWE83MaFHLOw/0cLTut0fPqdXEhrRsX6Cz29qfzLyHMyvamESaPap
vToJ1l+wggY0WY6D/Rbqz1eto2I3JzM/LTxmSd3QQw+S2fNr4TWrDcJ2lyfD
+g9uvzZz3EkE8VALR5fFFF7el4JSO9aP8FEn697W51JQQcf6Ei4V537d+BDm
W7Xwcgtlj2UKmL/Uxl1ul93Prk1h/to4rQjlRw5UsfbTxofu7fu+pr8K1r/w
s3pDh241sN9FG3/5vSB6ZBzM/2rj0u199jw/lYKOdayv4TXf+70e6wvzxdpY
NvGH1kxvWC/VxgErh6zqPhPWU7Xx8P5fDj5uTGbtr42Jfcz0uEcwH62Np45q
HZe1HuK5Dm6Y0OsmGgfzpTp4Q2NSSvRX8NDBcsu0C/2dwEMH9whY9nywuv5k
65P4bUBkv39NYX5cB5fZRVd8CVUwDx0cMWt9S8gqmE/QwSSuxd5VVwHrozjK
wsEz8wj0Tx281M/lqHa1jHno4JWPJ+hbu8mYh/p+olusWkulsD6LS32/zg7e
CetfuhgFhWkdl0uYhy5+uWDq/pV6MN7r4k35bp+XLID4pYsfdu9aliYXwfox
tvKL6WJzFObXdLH+we9xGQ4i5qGLB10Y+rm4IpF56GJXA9/VGw8lwvo1vo+s
te1aKaxv47t6W2PzgmC+UxebJJu17R1JmYcuNp/33YYcIrB+jo3Nrc+evpAA
6+v454Y+eoap8cxDD794k/Xk8T/xzEMPxy4dmbhjTTys3+NlYbcOjn4ZD+v7
ONi7d2hzQTzz0MPb4w627cqLZx56uE+YtpH5lXjYP4Cdf3ocSLCKh/0F2PvA
BaOy7vHMQw+/mvlo76oR8cxDD1eMoBVK9f2w/Qv4tEXmt7eR8bC/Aa99G//H
dUQC89DHvwpXnNtQlcA89HH6uOF2ChOon/Tx3iVGqt3XKeyvwENux2fHmMD8
sz7euObcxhNOicxDH0cUeASs2AIe+vjtG+0jbRfBQx/n7P32da/ai+3/wEU9
v+sO8xIxD31sqKNCS40hH9HHsh7tkRlhkF8ZYNlSgW/IuP/tP8H7LUM6D/4h
YR4GePqua4M7R8B6qQGOnLC4iDcb1osNMO/3dnFiDKwnG+Ba06XBNj9lzMMA
f1lXgAv1YL+fAba92+L8YyWsFxjgCcfsnjn9hPfDAL/3PO2QflbBPAywvzDc
VjRGyTwMsD7n+ijVE9i/YIAjpjn8Mh8C+00McTp3n/aoyCTmYYiP/th7aEGv
ZOZhiJeeKR65f00y7C/CBpOd0zu7JMP+I/yuvnxU9KRktKtjfxKuX15qGzEx
mXkY4ubb68vjvWD/nyG2HLXhx+y0ZNj/hEusS/tPt4TxyhAPWk+N+VtSmIch
jjaLdF/kC+cHDPGtymdrfYJgf4kRnptv5xp8CPafGOHMg05lOc4pLL4b4b/c
kcIeJiloWsf+LjzlhcunN9eSWbw3wn0mjxVMnJLM4qURVo6dUi0WQPwwwis5
7/Zd6QLxwwg/TpDUjh8H8cMI37rTy1VrbDLsT8Ou4z6cP1CTBPvX8AXHmVmb
Q2A+2AhbGw1Eb8YksXzBCL+bPH5Utzgli7fGuMdbWe64RTBfa4zXtw0rNfmi
YB7GuNOu3vMe7YL1J2OcuWHUz+IpEI+N8b47Tu2fRylg/x5+1f6l0gtDfDbG
llN362+3V7D61xjnxHLisztDvDbG+Yu2rOW8krP8wxh7e92nYfPkzMMYPxk7
o2XrX8hHjPHkdl6vnjLIr0xwhPCvxcMXkJ+Y4FnOG8x/34V8ywT/vNPkfue5
jHmY4Jqb92vz8yD/MsGNoz7JUQ858zDB0p4HZ8YvlzMPE0zuGntkrIL3wwR3
W+3L1R8G74cJ3r9q3lX/Usg3TfDC4OvW++Uy2N+JteNtB7wshPzTBFuEp6a/
GyJnHiY4Y9nq+OvLIf8xxelZghcxflB/mmJT1Y4jC+5CPmSKlwy3845Lg3rU
FG+f99H2//TAwxTn+7mmWJiBhyk+Zq9I+ZQlZx6mOHx1XP9vJ2D9wxTft/Xx
EzvJmYcpnri+INDrH/Awxa0VKe33joOHKX6u7+1+/oEc9ufi6Pd93ffchvl2
Dq6qqysRHof91hzc3YWIAzbLmQcHOxwTlm9Xjy8dHhzcs0fE1iXqfLDDg4MP
h90J6lUL+SQHj+3vrDx2GsYrDvZ7XeyUOBLySw6+ZDK27lcl5MscvCJo4UXf
SthvwsGTcnS703rInzn4mNw6y/cz7E9R//2QzRkejyGf5uDXTp4jdDZJmYcZ
DnCfZT5mCOTXZthwZ9/WxY0Qz83wwtsTplkkwH4SM5z18KDv3p1Qz5lhl8w0
xbuBUJ+aYcdhR4eb5UK9bYZzh142cHwuZvm4Gd7uudn5xXOov82wzPjbqUHR
UL+a4ZQj8/aMCId63AyXcUa/QDshfpjh2WWmd7wHQ/zg4ktlznld/sB+DS52
juqd1pwuYh5c/COC/2DRWxHz4OIXJl45L8JFzIOrHg9XHJzrCeuDXOxjM7LE
ZqqIeXDxnzjHPsaWMH/IxfzH9P7WOXDeg4uzDNb1C10J641cnLPQxbrXP7Df
lotHTJo44kofmG/k4i4Ljz7r+zeReXCxjl5Krw3ViczDHLd23qFf3lnEPMzx
yychQRdsRMzDHBcs6Ol6z14E5xuwRcUBO31ryK/McUZohHSgA+RX5vjW0Qkz
zU6KmIc5Lu87wVcvR8Q8zPFrVc7Jbr3BwxxfWtd1odwGPMyx0W7/hLMrwMMc
rzdXWq19Ah7mOP7zix69hkB9zsPlQ5dvpQ9hfzIP9/m/BYtuCv53fgQPE07c
f8dJytb3ebj0UmpMl2tSFu95eONZB7siLtSr6s+TchI+3ZKx+M/DF77Z93k/
HsYHHtbt/n7w6Cg4L8HD2gsnHIzjwXjBw69u6E4aGgz7+Xm4LTBr54JRsB7J
ww/+nK+slimZNw875XWTzbBPYvGWhz05Z17G3Uhi/jy89rvHxMbsJDjfg/tH
+7nsmAjxi4c5fo/H20VCPOZht7MNV/eOh3qIh0Pbxr0oiIT4zMN2Xy3nX2uH
+oiHU12i7V/bwfwmD+d3nVwwPVjF8g8ePlf0Z9yqNBWcb8KbxmQsTdNOhfNP
mHvt3ooX5rC/hI97po/RflOngvNTOK/5Y8+uP1VwvgoP6fXFuvC3innwsdW8
rhcDTVOZBx/X/5p602ZyKvPg4ydpFy5fmpbKPPhYP9QsxIefCue/8AqnNJVn
KpzXU39vuaTv6v2wX4WPr7gN2p40FM778bHuqUWl8ZlQn/GxY5KVVtnqFObB
x5YTTnv1/wT5Dx8fDkj9uGQ75A98/CZgQQuvL+RDfOw7qD1XUJcE5+Pw0pD6
Sv93cH6Cj90mOUc8tE2C83V4ZtKMprEXlXD+DtutmrbpdSbkf3xc1Gcrd+MQ
BfPg4xkixymBt+TMg489dT72+cKDeMHHHy4uK561B/ZT8vHgozE3q8pg/5UA
Px2bExh7BOopAY6KlEy2sof3Q4AdnP9Z2rcLvB8C3O2Vtf+ACMiHBfiQ3lDd
IbUw3ynA+jGDDKdOFjMPAXY73mWx/hUYHwTYsk9TRvIUEZyfxI26u75XtCbC
+Upc9WdU7wNxiXD+Ek/R/dv+5RjUAwJMNtXYTNuUyDwE+N9gK6HJZqgP1Pf7
OnSufC+cFxDge2l5Ge8XQ70gwPzJc8auqaVwfhS/uq7bfdVJCudL8aLzPseH
T4P97wJsV04G9rWG+k6Ayz50cr/lTZmHAK956FB87AnUewI8/GHM1ZKvlHkI
8IKv09LWmMN5ZQF+EXi1e+cZcJ5ZgIO3yJIO+SfC+Vr8ez3a/e52Ipy/xf0t
JT5a6vqmw0OID90+Ez1d/XwdHkJ8dPfd9GcbE5mHEH+3P6iVejKReQhx3fAV
/PC6ROYhxPdzikyj94GH+noPzj0NqQIPIb7Ted2Q2atgvlqIL6g6T/W7Def9
hNhFcH1d4lfYTyjEU8duCdrUU8I8hLjWw7T8/AwJ8xDiCS9K509wgfl0Ib5y
YvbiMd7/Oz+N7w6vUj25CPsJhThV/PHe5moJnL/Gv5M2fqk8CfmFEId5eGzg
WMD+fiEeVGOxfFsszB8I8UDd+NDx+pA/CXGVVNC/sT+8H0K82Xq0ZfZMeD+E
OLjrnp9jtsF+LiHO7HQt8FIw5FedcPHMzocdH8vR/wPB8FSL
       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0.1}, {0, 0.25}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"e\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {0.1, 
       FormBox["0.1`", TraditionalForm]}, {0.15, 
       FormBox["0.15`", TraditionalForm]}, {0.2, 
       FormBox["0.2`", TraditionalForm]}, {0.25, 
       FormBox["0.25`", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0.1, 0.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.869219844378491*^9, {3.869219996273428*^9, 3.8692200168687067`*^9}, 
   3.869225643827631*^9, 3.8692314731330023`*^9, 3.869231857019302*^9, 
   3.869231991798936*^9, 3.8692320537760468`*^9, 3.890977922793509*^9, 
   3.890977959564292*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"261e1e54-45f4-4f3f-8572-ac80f66205ee"]
}, Open  ]],

Cell["Plot the eccentricity of Venus.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"dcebdda7-a6e6-4f7b-9ffe-c694c3a1292e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pe2", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "evenu"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.08"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "eylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.02", ",", "0.04", ",", "0.06", ",", "0.08"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deline2", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.08"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pe2", ",", "deline2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869225751809363*^9, 3.869225916049211*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"678d4471-13cf-4fa6-8bf2-c51a800c6aa1"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923VYlEsXAHBg6dwwUWxFQUUMvBjMKNZVsFsUEzFQUAwMurthyd2lOwxM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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 0.08}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"e\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {0.02, 
       FormBox["0.02`", TraditionalForm]}, {0.04, 
       FormBox["0.04`", TraditionalForm]}, {0.06, 
       FormBox["0.06`", TraditionalForm]}, {0.08, 
       FormBox["0.08`", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0., 0.08}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.81139729748521*^9, 3.811397932550687*^9, 
  3.8677587012911654`*^9, 3.869225886782761*^9, 3.8692259173370533`*^9, 
  3.869231473324801*^9, 3.869231857112336*^9, 3.86923199193283*^9, 
  3.86923205384697*^9, 3.8909779228423653`*^9, 3.8909779596297083`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"eed709a0-c7a6-4e95-bf69-2e51c39efe0b"]
}, Open  ]],

Cell["Plot the eccentricity of Earth.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0094e0df-a937-4a45-85b3-4a7b777638ee"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pe3", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "eeart"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.08"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "eylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.02", ",", "0.04", ",", "0.06", ",", "0.08"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deline3", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.08"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pe3", ",", "deline3"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869225992340146*^9, 3.8692260231485662`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"8336b340-cc66-4922-aac3-bff0c2a1e524"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923VYlEsXAHA6F9hlwUbEAsXCQAVkxsAuFEUMbMUGDFLpkO6OpRsVxUBw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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 0.08}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"e\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {0.02, 
       FormBox["0.02`", TraditionalForm]}, {0.04, 
       FormBox["0.04`", TraditionalForm]}, {0.06, 
       FormBox["0.06`", TraditionalForm]}, {0.08, 
       FormBox["0.08`", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0., 0.08}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8692260242722063`*^9, 3.8692314735834637`*^9, 
  3.8692318572054787`*^9, 3.869231992057272*^9, 3.869232053929777*^9, 
  3.890977922886532*^9, 3.890977959675103*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"d3763a73-d734-46ea-9762-937ff9275e43"]
}, Open  ]],

Cell["Plot the eccentricity of Mars.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ea6f4316-2d41-492d-a413-b5f947e0f702"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pe4", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "emars"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.16"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "eylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.04", ",", "0.08", ",", "0.12", ",", "0.16"}], 
           "}"}], ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deline4", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.16"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pe4", ",", "deline4"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869226109331781*^9, 3.869226168679143*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"a1967022-e602-436b-aa98-75166c004b97"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923VYVE0XAHByadgwwEJQEFuxMGdssVssxBYVxQATAwQ7UBEECelm2V0W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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 0.16}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"e\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {0.04, 
       FormBox["0.04`", TraditionalForm]}, {0.08, 
       FormBox["0.08`", TraditionalForm]}, {0.12, 
       FormBox["0.12`", TraditionalForm]}, {0.16, 
       FormBox["0.16`", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0., 0.16}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8692261719155083`*^9, 3.869231473701476*^9, 
  3.869231857298005*^9, 3.8692319923233423`*^9, 3.8692320539793663`*^9, 
  3.8909779229300632`*^9, 3.89097795975056*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"5639f67c-e532-4df1-9240-4a388c35706d"]
}, Open  ]],

Cell["Plot the eccentricity of Jupiter.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8ce81f0e-c2d4-4cd6-ade2-db8b4d0fdc14"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pe5", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "ejupi"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.02", ",", "0.07"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "eylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.02", ",", "0.04", ",", "0.06"}], "}"}], ",", 
          "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deline5", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.02", ",", "0.07"}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pe5", ",", "deline5"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869226220864008*^9, 3.869226319811901*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"5dc628aa-c48b-4de9-883e-1cad8e408417"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923dczd0fAPDb3nWHlVUI2UVGRud4bEIhI4QSSuInih6bshUZTzTuva27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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0.02, 0.07}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"e\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {0.02, 
       FormBox["0.02`", TraditionalForm]}, {0.04, 
       FormBox["0.04`", TraditionalForm]}, {0.06, 
       FormBox["0.06`", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0.02, 0.07}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.869226293735054*^9, 3.869226320235333*^9}, 
   3.869231473809239*^9, 3.869231857391075*^9, 3.869231992432769*^9, 
   3.86923205402775*^9, 3.890977922973089*^9, 3.890977959795536*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"ec4545b7-fdb8-4713-8679-d66c3c2f8dd5"]
}, Open  ]],

Cell["Plot the eccentricity of Saturn.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d1d48429-3efa-47ce-8aa8-0d5823df2bc6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pe6", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "esatu"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "eylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.04", ",", "0.08"}], "}"}], ",", "None"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deline6", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.1"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pe6", ",", "deline6"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869226362013515*^9, 3.8692264679276123`*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"f0259726-77b4-41c9-a733-44e45d675552"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923dcjusbAPD2Hu/IKmSv7FGOcN841JFRKHuvU0SSaJ0cQimVSkpJe7/1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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 0.1}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"e\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {0.04, 
       FormBox["0.04`", TraditionalForm]}, {0.08, 
       FormBox["0.08`", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0., 0.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.869226470875161*^9, 3.869231473909225*^9, 
  3.869231857481662*^9, 3.8692319925319777`*^9, 3.869232054075614*^9, 
  3.8909779230164547`*^9, 3.890977959839559*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"8eabeca2-d986-438a-ac6a-a065c5a5d69f"]
}, Open  ]],

Cell["Plot the eccentricity of Uranus.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e18a88f3-e850-4812-bdd3-0585bbbd557b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pe7", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "euran"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.08"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "eylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.04", ",", "0.08"}], "}"}], ",", "None"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deline7", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.08"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pe7", ",", "deline7"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869226506718294*^9, 3.869226562886364*^9}, {
  3.8692317340762568`*^9, 3.8692317351980343`*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"35867f40-23ff-43ea-8935-c54317d425d1"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923c81t37AHB7j3vQlCgVSevRLueUhoaKr9Ki8khRpKJBMhJpICNE9uYe
Ko96pHMqLbRJaUkqmlZ2/Dy36/z887zuV4+P+3O9P59zruuc6+g77LXeISMl
JdUoKyX1338Hf7Roq36xsZStALUbbgm79ZtPK7ZM/ruqW4C+W13VPfGNT53C
rFunrBagD15awmUf+HT6imc+TqZ5qDrNfYFKNZ8u11gxwS8vBz2s+O+HTx8u
0Foz2jcH3f793wX5dKd+fIZ7bw7672pWV/k0bOL2V2bXctDAxQauyKd/DnUu
bLiRhdL/u1wan06YGjXMLyIDXYj774dP73hUO9RXpqOBLzdwQT6VDra0dhiR
gf67mu4JPi1x1i6bMiUDef/39bz49GLRNWFWQRra99/l3Pl0TqmfQaZxCnKS
/PDpntvzL6l4J6Etkgvy6YiyyGUFbknIWvIF+dS95Rj/SWcSspDcMJ/aPHOT
c16ViCSXW8CnYzYMWyTrE4f+kvzwqb5Hy/PdJtHISHJBPn1evnXhwklRaLTk
C/Kp3ZG3r5RKopDk62nxqehGgWjdrCgkuZwKn359qZm0JCIcDXrw6bY0y9iD
t4PAg0d/CP0wOuwPHjyavj8/3bDSHzx4tNjz1S/z+QHgwaPBG2evuVnlAx48
ekXZ9Nm/3fvBg0c3je5R/rDcDTx4dP29f+w8S3aDB4/aJE30Tf7tDB48anFO
p3PntkPgwaNjJj9c79J5Ajx41OOS3M127VDwGLj+oYZ9ByeEgwePKvKmrj2V
GQYePMr/WXBiQn44ePDo2YPDvoU1RYEHj1obnrb9sPICePBoz5Da66YlCeDB
owVH56WWJyWAB48+2+J/2r8gATx4dHb8Pf1vrkngwaO/ZJ0yHLenggePLlFX
uc+bkQ4ePPreeLOOz5Z08ODRBNXZJ+L00sGDRx8NN3gSVp4OHlwaeuDJMf2O
TPDg0vu1c0O8DHLAg0szHF38DOJzwINLuSaqgqcG7P3g0vyN6Bmem4Mk4bvF
pea7Prhk5OSCB5e6Ke/hKT/JBw8u3VJ324smC8Bj4O9dt7lxXUYAHlz6OHOx
mnRkPnhwqecuE7+3iwTgMXB9FZMT15RE4MGl6n/jebI8MXhw6Vb9qtsqwSLw
4FKZ1FTPoDgheHDpd4cLRbOTheDBpeEXPUOHPBeBB5dq29kpPgoWgweX6o2P
1Eu3EYMHl5a+l3PNXScCDy59qR4Z9vqWEDy4VMtqZ+fkLSLw4NI9j9KXhC8S
gweXbvxKjpkgMXhwaa9f6c87/ULw4NCwRrth8tVsvOLQB3Ku9ZEf2XjFoTPH
Xwr6WSEEDw41lbl55L6RCDw4tA+1fb7zXAAeHDqp+O9bkwzywYNDo+Z/snye
lgceHKqw8Mjkh6b54MGhrat0A24MeA16cOjtsCsFHxvywIND7b9ZaF3/lAMe
HLrVb93N/bezwYNDNXivu2S/Z4MHh3apxv3ODs0BDw79emW0W4BRDnhwKMfj
EO+jQRZ4cOg4jfk6ztYZ4MGhS7g5DX+1p4PHQDwUze+OdMsADw7NGmIg3L0n
Azw49M7J+qP8wjTw4NAp39afN1ubAh4cKpWnPOLWomTw4FDp3ku7C12TwYND
m49tOqgYlwzx16SVlmm60y4nQrw1aZyulcaMPXEQX00abK9oo50fDfHUpKnv
tBwcJ0ZD/DSpc02qiVFANMRLky4qcd1W+zMSScLtrkn9ynYLLYaEQjw06fNb
r3Xyo4/D/WvStS3vT22x9IP71aQ6VotGqtz2QxJOXU1659CsX2GpPnA/mtSJ
z+N8HOUOz5MG3T6xVH5qujM8Pxp07gOXctlfB5HkcanQoK3f+uy9FI/A86FB
Kzp9tQ3Fh+F50KCZB+uPFU8PQOGSG9agf+2w5h56cha8Nahd7YMHB6UiwVeD
Rkrd6y54HwmeGrR59Guz2tRIZCb5ggN/78IXNEWHzS8aVPu4it13qQvgo0Hn
Hdjo8+V3Inho0NnCus/InHmoU4WXP1wWKCaDhzrtPL9zOt80GTzU6a7Q98sz
P6SAhzodPfofNM85HTzUqX3M/ir9JDbfqtPymoCuhk0Z4KFOx5ba9W0emgEe
6rRts93Q9k72PKrTO6fn+hUZZoOHOo0MLNLbejsHPNSprc/vl6ZpOeChTo1k
3lkpK+aAhxqVdyp+8XMBG1/VaLhjfKrU81zwUKOmJt7pTWnsfVWjJvpuUQVv
2PupRnU3ur+rVcwHDzX6+siLUfeK8sBDjfb1P3XfkZoPHmr06ESNwtrtbLxT
o63/s60QcUXgoUaDfybZnJ0jBA81GrKdN7bRUwAeanSU9Ld/Dt0TgIcaXeWq
LLg7TQQeqnSk0rh0k7Fi8FCle7/r2WjnisBDlV5RmChb7y8ED1UaGGz2v7kW
QvBQpapGFgqbZorAQ5WOa+Ce2T5bDB6qtHn8VjR5lBg8VGm+muMI7UdC8Bj4
fU+j7CVSQvBQpavxggq7HULwUKWPHbYU/fISgYcqPfjgNo9ki8BDhd5tej+0
crIQPFRoUUaF68wb+eChQjf/nI5rQpmHCo31O35lxEo2f6lQ++867oqFAvBQ
ob2GiQtO7MoHDxVavNjU0v3vXPBQocv54o9FJ3LAQ4VaC21UjZ7mgIcK3Wbo
PmqYeS54qFAtgzl/Xq7KAQ8V6vY2RSmzORM8VOhSE49klVUZ4KFM43UXHM0a
lgEeynROjzm1GRgfBz2U6c6ZY6lRdTp4KNN2rfDN7UGp4KFMr70qT9lnkAwe
yjRVWBJ35lIieCjTl2/UVlV0J4KHMh0+8dH1WZ6J4KFMs1RemZjmXgAPZep+
6eHU37LR4KFMZxhrPuV2nAMPZZpcOmtOWNk58FCioTfsXxYUnQMPJXpznqcw
1jMUPJRob5r689/Pj4OHEj1q1Ty9rNQDPJToX5eKa3x73MFDiUZVHhotJPvA
Q4n653XwPo9xBQ8luhs/5Qdd2AceSrRu4uo1hvrHwEOJWhUOW1F5yx88lKj7
z8Y1m8f5g4cS1f5QyfuiFQAeSrT529zNTt9DkCR83xSpUnTPjLbZEeChSGta
wo21q6PAQ5GWeQuvjCqMAg9FOnLHixq37VHgoUjPTbuLWvzOg4cizdX5Mupy
QDzMr4p05qrTm6fYsvxfkbb+TA878pjl+4qUXlUYeVsrCTwU6aioaI0tlUkw
PypS8RZD8yc1KeChSFcH362cYcTyQwVam5xr09OYDh4K9HLgwXVrj6dDvqFA
Xdx8fOL3pIOHAh1bFvW7IzMDPBRo6uj45Me/syB/UKAbwz6bV1rmgIcCdZN9
YndUneUHCrTiAderOjUbPBTo+bM6MzbMzIH5X4EeFKiaBOnngYcCVTW9nJ7/
OR88FOgbk8mLPnfmg4cCnRBu9lZzZT54yNO9nwJ+rbfKBw95Gheh0voqkeVL
8nRL4r4bbodF4CFPH+8X07gmEZJwxMlTHfe/8V4tNl7J0xPxia/CIoXgMXD9
mjFX3s0SgYc8nV++/vM9RzF4yNOxsgnjY8tYPilPU45yr9TZisFDnq6VTx//
JpmNV/J0e5bGCZrCxis5umuc2Yf2DWLwkKPeXMP1S56IwUOOLtZqPP9irxg8
5KjGedkiaUsReMjRujXjvBQyheAhR49sf1hUaMDyaTlqPL+qbXY/y5/lqPhO
otT4gXx60EOO9uYTn/I0AXjI0TQVw8vrLfLBQ44etdvtXTOLechRue3KU92q
mYcc3W4nqL16mXnIUh2ZZ1lVL3LBQ5aGx2gd3vEkGzxkaUnd4advB+bbQQ9Z
Wvir9NsWn2zwkKVz+EcDLiZmg4csFRkH7EgckwUesrRqw19Rw0Xp4CFLXQMd
2sM3poGHLDVOXC26PfB50EOW+idNd3NJZvmjLH2Iog8oFqeChyxt6dY3i1yR
DB4yNC/h7PicowngIUMtzyzTen4hHjxkqKpG9JZ1JgngIUN7kp9Zvw+JBw8Z
auVgYWGbGAMeMlS0+mbFWr8I8JCh/+q3RY9YxOpLGXrZ41Je6Klw8JCho+aq
by4sCAcPGVq6a/VI8/wz4DFwPbnyMemfA8BDhjr1BoxaZecJHjJU3/6vN7YO
+8FDmh7UcSsW7fYAD2naZzFk6v4PB8BDmu57kVHv2OEJHtLU9OK3SFctH/CQ
plahQWac0b7gIU1HzvXfpOzsAx7S1BttbU276wce0tTxwiL5i09DwEOa5o6p
K5zWfg48pKn2s8C6agO2/iBNT+o2ROf3R4KHNP17+PM3/UOiwEOKtqyOEinK
x4CHFPWVL5uv750AHlJ06oZk6zBOMnhI0SJfs5GXliSDhxR132OtHTY8GTyk
aN7NurJ3NcngIUX1/HZpq0xJAw8pemX1alsfnwzwkKIqP/2FgUMzwUOK5soa
Lyy8w+oTKfppeFDmwoF8ctBDis5LMP++LSYLPKRo7StDi5MdOeiFJP79ZNNR
jZ99fbkQ734yymLo0XsxuShQEt9+kn961YxhVrkQz36y+mhhyrzJeWi6JH79
ZPhJK9nKGQKIVz8R62i1b4gQolpJfPrIR6+2CkdTIcSjj4xbvdD6phfLZ/qI
S1zgAlGOAO63j/CidUqbtVn+2Ee+nPwW9cNCDPfTR1zTLo6qnC6GfOQPaS1p
Dl5twfLBP8TFPjKvqIblf3+I59ktN3CCCPKLP6Q56vGHMUfZePmHmMq2OieH
iiF/+EM4ifs2aJez8bCXhPurGoXdFUJ+0Eu03+fnq38XgmcvKfq9fLtvhwhJ
bterl2g9fON5bCC/HPTqJWGi+iTtgfxTcjnDXpJ6SqVjRTbLd3uJid3hm8Pm
C8Cjh3x3XbD8d60APHqIz4KF3ZPOCcGjhxwpnn7NpUgAHj1ES2t4X/ET5tFD
Js7xvDD7QS549JB9sXU2MtJ54NFNhlxLCtUdyOcHPbpJ4d3O1M9b88Cjm3iL
TpXvOMDmy25ioDrb6ejdLPDoJgtPnlwY6pcFHt2k96vWqz0a2eDRRW7vDHn0
PwM2vnaRTPNIO62gTPDoItOV9Gs+rkoHjy5i+1yq5osDGy+7SKWHZ7YgIw08
uoiL07kTI5rTwKOTaJjP1j3zOBU8Ogl3mkW8qg17vzrJ5i/Wy6YtuggenWTM
5bGTpv1IAI9OssreYpFjwEXw6CQT18xbWzgtATw6idLxdeZfjsaARwfp7cri
XY+KAI8O4qD870kltXPg0UGMNqQYjdp6Djw6iM22qz6nisLBo4N4+a2w1awP
AY8OorSE/jOm/Sh4tJPfe95trDFxB4928kV9/JS/frL8sp2cvPPY7lIzyyfb
yRyRb+KFkq3g0U7yDLK3RnoeBI928jWgeqXMvwHg8Zu8K70stf11IHj8Ju70
8fSrwYHg8Zu8CU7Y8/lCMHj8JvJ7bWZf6Q0Hj98k9v3EQ+WjzoPHb1KQtflM
9q8Y8GgjhzYP1TYqigGPNmLJHWMkPy8WPNrI9leBU62+x4NHG9k2M1CDI0gG
jzay8FaUhaN6Kni0ES+ViOTjbSng0UamCI4dqX6cAh6txPFB6tJ5r1LBo5Xs
i+j3uoYzwKOVLG+f8ogoZ4FHKwkPGGs+SzsLPFqJzk6RbmNCJni0kpUBZ9Jw
ayZ4tJBNH/44517LBo8W8mhswTi1olzwaCHRFwKNzvDywKOFNBfe3vViay54
tBCXFxNKZhnmgkcLqcsWKSrPyAOPZuI8+xhNHsnywWZCHF5UHq5n65PNRNXu
y9VVEwTg0Uyi8n/s++6VDx7NpMTeOXjxh3zwaCa20reeTd/D1veaiN65nw/U
YkXg0UQeu+1+fpTL8rMmci5u3VtjeSF4NJHEQjfj7e8E4NFENNRVtdK+CMGj
iRSV+JVN02PriU1kTMmlr81cMRJL4v+LrF2q5S/3Rog2SOL9i0TTo6tPTBIi
JUl8fxF/xZnz3uWx8f8nyZ2QiiwaRGiXJH4/iYXGsyInXTHiSOL1kzxSWp7i
2yxEVBKfH6SmqFL1upjF4wdJN5u6SDpVgPQk9/+DhAptYuRPCtETyf1+J90y
vQ4VA/nmYcn9fSdrjgTJ9Wiw+/lO5rV5HCpdmo9eSp6nb6RL0d3sUVQeOjmY
oJAhtqLSHwr5aKrkeflGRjS0pn4X5MPz8ZWoXXls7v2LjZdfSePp5w2RA/U1
lvh/JRq3Ly+aui0bNUgu10j6A0rzVVZno1iJbyMxrbXo+KciGzwbieYRd5sO
p2zUKfmCDSTAr3TfmiWZKFlyww3k9W7exMNa6WitJIANRLzTXKt8Rxp4NJCG
nGz97tQ08PhCcpubn2/1TQOPLyTr0NnOVkEKeHwhPh9KulHTRfD4TPYddCtR
HxEPHp9JwMEj8j3dF8DjMzmXF1EY238BPD4R4xMrjBxdYsHjE/mf4xV/VBsB
Hp/Ijglnz1Q0nkH3JR71ZNzKC390xp4Gj3oy/f2GR+kep8Gjnux/Et08J/Ik
eHwkTWcdfd2qfMHjI1E41fbv1K87wOMj8Wlo/7lwyjzwqCMhYdfmrplrCR51
ZGKDTWhi/RrwqCNLbda1Z+/xBI8P5NviPUvTIgPB4wNxcXVakH+V5YcfCLb7
lD/qWQh41JJRV7fpDnUNAY9aEjS+ZOapVaHgUUvkP4VbkD1R4FFLni8asSVq
eSzaJon/e3JjoY6f06tYJJbE+x3Z4TxefGl+LMT3HTF5PsrmxoQ4iOdbMm7I
/5qJ9UV4nt+Q0FobN3uZFKQnidcboppgsWnT7RTkJ4nPa/J21vriYKcUiEcN
+ddOcck/m1Lg/mtIy7g75kicisIl9/uK/IqKCNHXykBNkvt7SQwW6eGTezLh
fl6SW6gbLTTNhOepmrz+B12rr8xAnMGEnZz5WWq13CsTbZM8Ly9Iokr1+Z7j
2fB8VBHbj9P0t27Mheehinw+aJea452L/CT+lUSjvuvoq/oc9ERyuedErbiw
b31fDvg+J3d2TB5xzo29X89ImFhYftdNgJokfk9JUNik7DnKQoQlXk/JgqwR
72esF4DPE3L7883hK9tZPfiEyH4tj75yQ4CoJP6PiJubbumuIBHaJon3Q7LI
P2ec+2IxxLeCoGMds9TfiSCeZeSp8o8b62VFKFkSvwfEQWVdTYOxCGFJvO6T
ufh4i9LcgfFREp97ZJdclcbTZ2KIxx2yZs0JXd8oMdx/KSndXWQsfilCepL7
vU1qnjSHOmwb+HuS+7tJsv+UHndXFMP9UNKhM5n3Y+D3B7//DZKfK12Zd0SM
sOT7XidSDz0uxVmLkJ/k+10jevePX/tiLITvU0SeNaW7pWEh/P0rZMOuiIrF
A/OBlGTALyCGT12XNuoN/L7k+kKyLc1ZevtBAVwvh5QEjQizTM2D308nF//+
S3na8DwkJSmYEkleiKWlzqmBz5J/jyILb9weE1HGPgeS/Yfe9Fk55bL6Q2rj
yF0Tw7Sy2b+jHaVP2zNeZyIpbcnvoyo983fBDZns+uhZTJRV0rws9veRp9X9
4O3rMtn3Q8O8XaLbGtPg/xei1XUOt050prD7QwubHcefjUhh948eh2q38d6m
sPign3FtSbHHUhAdjB/KmzhkTXRtIosv8vz9iOa8i2PxRwXlxHvyqxjmg9Zs
ulX2ZEIs80Nbkwvels2JRXjQF1nVGinb+kczf1Qm01qRuzycPR8owHvW+A6L
EPb8oL+5V36tCz2Jtg0+Xyj/wPYxxQEh7PlDMhmFDz0WBLPnE7Vdzp8cm+vL
nl8kM2/HutAVrshv8PlGFWXYxH+qNXv+0TItvd8HTa3Z+4Fc7GN7nozYyd4f
9PZUv8kfRS+0dvD9QvxJwxeZZQay9w9du2hlP6symL2f6Mwkuya0NJi9v6j3
zrAmVb+B7zf4fqP23Ah1vY9n2fuP5h47vbZ9SxQbH9Bd452BzqUxbPxABzYV
6PylPzC/DI4vCPec6n30KIaNP8j1jYnNov1xbHxChaZubuOsE9n4hVacOyRV
NOAJ4xuKVKSL1celQvxeIeelx9IDvvz/+IiuPGrJppNS2fiJRMqWiStb0tj4
iv7lm7oN985EUwfHXxTYq+VonJXFxmc0T/rS6EPOWWz8RvNXS839tiiLje8o
Ney7k6tFNsT/HVJwVm3wPZ3L5gfkrBaW9EmfjVe1qPpQR51lXx6bX9DL97vv
WXjmoezB+Qct6X/nFFeRx+YnpHaDJwjwFLD5Cwn4vXWOM0RsfkNTIicta1ku
Ar8PyCUq4mH1TiGbH5HOEespQwyEbP5Ez3QqOsuHsPGvDqXd09WdvVGMZg/O
v6gjYPfE6SFiNj8jg6n0pk2XiM3fKNfTtuK4Hqt369G4nyUuwbtYPlaPIm/N
s+m0EkP86pEWMomenyFm+QOK8LIXVeuw/ZlPyH5x6pu9VSwf/IQu5sXHVgYI
0bDB/AQ9GrrG++Jilk9+RuWvc9wjlNn65Ge0OXn/CZ+1Ipb/oIidEd1LTgkg
/l+Qq6B09dmEfJY/oWlePRan6plHA3LOWLNyuEjA8i/08/WcWTxHAXg0oBCH
8ddXnmEeDWjy9wTTywPzGeR3aHSyCdn9IIflf2jYJdFF01254NGINPldBXvO
5LL8EXWQvkMH/2Sz/BL53D/qWfeF1SdfkXf95E+ZIzLB4xvyLmp7puOeyfJX
JJL75SB6lsnyW9TeVjBG8U4Gy3+RbF7fp4d70lh+jPpyrDmu9Sksf0at0Y1u
jk9TWH6Nvj9p/3fq7FSWf6OdPo7vaX4Ky8/Rl+Rz7VoD4+Wgx09kHcBx1Ft/
geX3qM5ABkvJxbH8Hz21LVloHxjH6gO0TDh80Qf9OPD4hTSrnu4d5xPN6gu0
1wSftu4JY/UHSgn6bHHC5BSrT9C05Z+v8gc+2wzWL0iPtJxW0ziFjg7WN+ih
dvahEVInWP2Dns6SKQlw8mT1EbI4OK49W20h+DUhuTO+G/ZrbYb7b0annn82
HFe8ntVfaMUXOwP7FQ6sPkPzv+0g864fQwmD9Rtassc/QHtOCCodrO/QJm9P
2TPaZ1n9h3QrX2SrdZ5h9SHS2HVTfHVUKPi3oC7tYYXt8pEQvxb04PRmg8lX
Yln9ic5d76+LuBzP6lPkY9LkofcwntWvyKjM1lVYGI/UButbhK5eNdTjJCLT
wfoXeccv/WOYnsLqYxTrbnRBJj6N1c/oiWWFQLOK1ROtyHrem/fDA9LgeWpF
oTu1gpZ1s/qjDQVusUid0sGerzZkMW3CiDbDbPBoQ4LQ6IzqgmzwaEMdezIe
vhv4d1gfQEv91y4t1Mxm6wdIqy4jMH1ZDni0IcTnHp+4LQ88fqPb0QobFq9m
9fBv9OPEgfdbC/PY+gWS9lUwWzkuDzx+o4WNZqeXZ+WBx28071G3ecUm1v/y
Gylw9n5ZlS5k6yfo3I7rjU6z2PjYji5PcN9/Z6kAPNrReZPD/M/T2fplO/JZ
pd0+YiOrb9vRh1Jqo/yIjZ/t6Mpl3+sJd0Tg0YFGXy+b73dBCB4d6OA3J9tK
adY/1IF+v/E83Xyerfd1oH0nm+c0tIjAowNFj+BlFU4Vg0cH8tn3cnX8LBFb
v0J3L7ePXDWS1bud6IJIcaXNOCF4dKKh5fOP/TERgUcnOpFYP/l1M1sf6ERe
vUvsvRTY+kEnehGnanttnwA8OlHHysVJQz/lg0cXmnxF3zTGi80/XWh4wJro
UdZCtr6H7r46YdV+VwAeXajS+pljZT3z6EKuVqcNh2XlsvVDdPX9Cbn1V9n6
STc6fZorxXXKA49uVHVRae+9GXng0Y2yNBdt+GdVDlu/RPN67u3cti6LrW+i
xhDbwzvK2PjZjS7XxMfKG2eBRw9Se/tX0kvTLPDoQf8kWK8dfpb1Z/Sg7eqW
LWcU2PvRg1on0qiAGyng0YPCzKt1NtxKAY8e9Pezxj6nD2z9qheRO3t3TclN
Zuu/aEtR3aGz3+LBoxfNykt9e+9mDHj0ov/1ncz2/XaerS+jKDWz208N2Ppa
L/Ix0z2enBcNHr1ovHedT8/7cPD4gxzuTTFXfhHE1rdRiYXL5BUVAWz9G12R
0ey4MeQ4ePxBS9WjUl4PlPCDHn9Q37KKKzNmHmLr60isl+RheseJrb+jjM8X
dmuauINHH+IfdhEcT9sHHn0o/4WCokItW7/sQ9Ytaw4o2xxl6//oVGLQystj
Q9j+ANpqYacxa384ePSjzF3NT4dOOQce/chtz7VbS4vD2f4DunXk6iTV12z9
tR/FnFd7e8T+PHj0o/ecdwuNp8eDRz+abiDmnXrA1nelMN/lvN4/0xPY/gi+
f/7U0PJ5CWji4P4J/vFh2IaHxkmwnieFq2fcfxXES2X7L9jbzLnwpev/78/g
kK5x+9RQGvhJ4XGG/ma1X1Ph/qXwy/gYpyPpaWz/B/twrjkdKc9g+0PYJCJv
2ffsLPRocP8Iv4uppYKnWahucH8Jj0or8euwyGL7T7jhg0naSPcstj+F16DZ
k64P5AuD/tK4ynWPrmBIHsRPGvsWT19ncTOP7X9h5YCFjQET8tj+GM532jPh
3ZtceD6k8WvO0hMZA/9/0OD+Gg7SadLnX2brk9LYNVtx6uga1m8jjQtLG88Z
Dox/sH+H9zzeWSiTKYD4S+MrjxZyLv1k4600tryj3+y4i41XMtjq2+k1K53Z
/o4MDjMdaqdrIQYPGayBRn2o8WL7QTL45krHlb2T2H6xDG5UG6aXLS9m+5e4
teR+1+XLYvCQwZordWL0/hWDhwxOOHNplIeamO2P4r/bc8gDQxHbP8VuX17F
fNspAg8ZXDtz75agOWLwkMFzTmWlBWwXs/1ZvKXtyO2/N7L9dFmsozFWfuxN
tj4pi50TpgcesxeAhyzmiY+EqnSx8VIWP7yR77tpNxv/ZfGEvvOla2ew9U5Z
nOFx1rFNm3nI4lVW0ZOfSeeChyyO3O5oHzie7d/J4lnD60Lazuey/W2sqq70
+eOdHPCQxYkbKvtCD2SBhyzmDFOdNCUtg+2f44fetoK0lWz/UA4rmNXMOpWc
AR5yeOrbEHHQogzwkMMfJpz1fjgpje3f45CG7p25JJnt72OZE6kRyclJ4CGH
dW8Ixno2J4GHHJ50eMsv74HP0D+AOwo2zupvZ/vZcnjFhL2rAjNjwEMOB/ns
QRqrosBDDq/9NNk6UYntz8rhBYfcv7t5sH5xefyt8kkr+cXWJ+XxsH+PnjH+
5wx4DHyOu8UZZ8j6IeXx4qx8HSNDtn8sj5Wjt75VGe4PHvK4bfwMvxXEDzzk
cd/Qk+4Bj46Ahzy+L8q1/XlrP+vvwIp7w6Ksh+xj/R9YZXtgyb1CV/CQx9Uh
c3q4Ee7gIY9plVXmQy9f1l+CS+8IIyr+CWH9J3gmt8ZT4BEGHgpYWkFmWHBV
GHgo4EPhx+MWjQ1j/S0402zxq7d251j/C9bcYnHUzeE8eCjgEctnWXTWXwAP
BXzDYtyPAzoJrL8Grzv6Jlo9j+WbCnjpEK8/ccsTwEMB+zmXzdVVSgYPBdx3
egXvZloq6+/BJi8Mi5XepLH+H9zzU2FCSmEaeCji7Lt1k3+lpoGHIj5v8E9m
8P101l+EXfmvxuTPYfs5ijj0iZE6rzMb7R/sT8JzE/ud46VywEMRj7hgMn5W
Yjbrb8JewSvm+w9j5ycUsWHIPbknXez9UMRD5K4a23ew/QBF3O/i/3aRBRuv
FLFvturJI4msHlTCUgnxCY+Os/4TJXz85E9tjTwBzO9K+JizgZ3naRGaP9jf
hV0PTIl7PUQM870Sjp52dVieDatXlfDc0FZL/XwheCjhGKPiT/t0Ray/DE/w
0otpX8HGKyUccS1oxr7rrL5VwuGqHruvrBWz/jW8a9MQQf1eln8OfN4wt6zf
TAT5ghI+cdYhzFRbDPOtMi7gldjFRrL6WxnvsAy9pb9UDB7KeOcot5HGzawf
UhmXVe8+M2IMG6+UsYHBund3/Vm+p4zn1i5L93cRwfysjBvP7lo55v/XI5Qx
v79Nft1hAczXynhYpLvLM+V8yD+UcVWLTVnyQH446KGML/yq0vGOzmf9h/ie
7zSly3eZhwouPlLtNXJxHutfxNGrV7Z8GMgHBz1UsN7J+43PorPBQwV/tx3p
O6mL1Scq2KFpfmutSw54qODZ3R6ON51YvaKCl1ft3lZulMn6L7HmvmhBVWk6
68/En17l3D1SyvrTVPDC/UV37XAG6+/ExPzXfLN76eChgj86q25+l5oKHip4
eKXSG5NTyeChilWmzrQ535MEHqr46wQHee11yeChiqsU1ZeU4GTWn4pTHvS/
61K6yPpX8XLb41J51TGsvxWHK5gcx2bR4KGKm2UtWv63JRo8VPGrtbZ6FqGs
3lbF5Vo34vSMIsFDFe+X/l/MBuFp8FDFP4dsvXunh+0vq+KuN2Z9+4P8Wf8u
tvwjp767j/UvquFd7nX3Nsw9Bh5quFY1vqPfby94qOEJ5fuEXw65gIcaVhcO
2RV86wB4qGG/+8Y1NdIe4KGGu3PHVr0v8GT9ydhmomNFod1x1r+M6Wn9a73F
oay/GfOV91qq7olg/c+4Vm3l7LirEeChhsNkjMstiyPAQw2P//ElXWlVNHio
400WFV7bX1wAD3WcZP9d5Y5CEnioYx+LYC2nctYPqY5HvP27gexg/ZLq2PXg
96may5NZ/zeOeaDcuNcrFTzU8RWz8pbM9+mQj6vjTMzdIxOXAR7qeGuyrP3u
+RngoY5b729/22meAR7q2LlS8GV6Pjtfo44jfE/9WdmXzfrbcVNJuJGfDqun
NHCKx8s25wL2fmhg696mllzzHPDQwJ9PT9I/2JgDHhr4wkLDj+gJq7c0cLn9
XIU0cwF4aOBJWX55h3tYv7gGnrLFfduOSayfXAOnVf/c0D2V9Tdr4OKAmeXj
jwrY+QCsIfvMfJIWG6808KGL4SrFBmy80sDVKy0OrhgqBA9NnPP9m4F5FMuv
NPHOJ3Z1pzCrpzVxnpLBYa9idt5GE7fPLVbzHs36uzWx57HQofunsH4gTdys
7DbGYQqrtzWxkPC6glcJwUMTG9ucL7Pez+pvTTzxnI8a30gMHpp46PW/5ioG
svVPTTzt16Pq5iFCdr4Dux2KrwrPZP0+HFxtfWrS0IF8Gc6H4G1xCj77bdl5
Hg4unFRU7NnK+ss5+HWb57DzA/EenO85uLlkqGvC9Hy4Xw4ueYqeXv87H+Z/
Ds4x8LDdvoDllxzsXb3vk7kZ29/n4N1zo5vOnGH5Pwe/fNzP+fbo/8/P4Nj5
FeiYcw7Eh4Obni/vet2cA94c/OLP+0eiybkw3w58P6VJ3sX/svVKDva4/WHm
W1fW78PB4aN2iEevZf26HDzFqd3Ial8GOx+EH0xZcOXBNVYPcXBbzpy9srnp
7HwRNtVNK5DVTYV8g4Mrdvncnzg9GeLNwUNdomVPFyRB/sHBgS4Pnh1VY+c5
OPh6/N49weWJ7PwTJgXRUgKVC+x8FBZEbPiY+5Dli1z8y73lfdqnCHa+Cq+P
Nt39VTkSPLjYpUw7180pAjy42JCrMMzwwFnw4GJa23DV560/eHBxoUHwlKpM
T3b+Cwu3Wh3ZudaTnQ/DI0enLY5FHuz8GL7VYqidLeXCzpdhz28OupdK94EH
F4dxdOWSnxwDDy4+M84yuGmTP3hwccm/w/6Wp37gwcXps3TWvtx4nJ1/w+2j
u/YfGnuWnY/Dlstj0jWCItn5OeyNAhsfLI1m5+twaqfU2aw61k/OxUaZx9eY
aUWDBxfbbtKrmWQbCx5c3HrXeIdB2EXw4OJugdnC2CnMg4v3T+taM5nP+lu5
2HF3uJk4MYmdH8QX7WXTnqex81M8HL/Z+caWH6ns/CEO8r220L4qHTx4+FfM
qqFrFVh9wsP6O8yNxp9OBw8erozHqpU0HTx4eGay32PRnkx2PhKXBWQ8HhLL
+sF5uP/YEf+Ry9n5MR7uGlkT8+5GNjt/iQVXp5nJBWSDBw9nSnnoJB5j7wcP
tz16X24dxuo1Hla3ySORD9j4yMPOk0/0x2xn5994+Fap8Fnc/Tx2fhSbuk/n
PDZk5xl5+JJJadyVMgE7f4p3kDHu6+xYvyMPPzs0/Pn4xaxe5eFdvsvahm4R
ggcPu1Tpjc0bGN8GPXi4ca9e067Z7HwND1PL+2NvO7F6lodDkkPUDE6xfh8+
Lqqr0zPpYPUtHz+cXj/00mw2XvHxkU8jpyWliMCDj4dZLC5w82D1Ox9bN6U4
3Cxh+SQfO5z4xfE2FoMHH8foyuQ4/2H5JR/Pc1+2ct0ddp6Ij1+qjHMwj2D9
7gO/fz37o48+q/cHPg//MVJ9JRvP+Xh2nN7IKy5sfuJjc7+yJqOBfH3Qg49H
VJ9zH1LOPPhYY6iHb5szW9/g41eVa+6cKmXzFx8v/Lr441/JrL7m4/sxWhu+
drP+MD7+aHlAL/1f1u848Pv3XzuWGOaABx9vOyO68fJ9NnjwcXBLzF3dmkzw
4OPWBN0FE86ks/Pj2H6F11qjAtbvyMdnd+jMs/7A1tu18PXb3/U59Wno/wBx
P4RX
       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 0.08}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"e\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {0.04, 
       FormBox["0.04`", TraditionalForm]}, {0.08, 
       FormBox["0.08`", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0., 0.08}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.86922656328728*^9, 3.869231474007831*^9, 
  3.8692317651735363`*^9, 3.869231857571898*^9, 3.869231992631392*^9, 
  3.869232054124132*^9, 3.89097792305888*^9, 3.8909779598827868`*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"0ff5b2cb-73a0-46b7-8648-cd28b6acbacb"]
}, Open  ]],

Cell["Plot the eccentricity of Neptune.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"02372833-7e78-4b6a-9113-f227463f5964"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pe8", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "enept"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.005", ",", "0.015"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "eylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.005", ",", "0.01", ",", "0.015"}], "}"}], ",", "None"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deline8", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0.005"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.015"}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pe8", ",", "deline8"}], "]"}]}], "Input",
 CellChangeTimes->{{3.86922661366822*^9, 3.869226631366857*^9}, {
  3.869226684543605*^9, 3.869226759401021*^9}, {3.86923174941951*^9, 
  3.869231753122867*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"f755e812-80b9-465e-8395-aa600949727c"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923dcjd8fAPD2uo07sokQIjtbzsnOiPAVX3tkZibVvY27V0YIZe89KklI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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0.005}, {0, 0.015}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"e\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0.005, 
       FormBox["0.005`", TraditionalForm]}, {0.01, 
       FormBox["0.01`", TraditionalForm]}, {0.015, 
       FormBox["0.015`", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0.005, 0.015}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.869226750156252*^9, 3.8692267597634563`*^9}, 
   3.8692314741076393`*^9, 3.869231756208335*^9, 3.869231857661458*^9, 
   3.869231992731186*^9, 3.869232054172049*^9, 3.890977923103458*^9, 
   3.890977959944676*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"a8850f3a-8e28-49ac-baa8-d5410ed6e938"]
}, Open  ]],

Cell["Plot the inclination of Mercury.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e5e6f166-ef72-43d0-bdb8-abb26bc1d528"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pi1", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "imerc"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "12"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "iylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"4", ",", "8", ",", "12"}], "}"}], ",", "None"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diline1", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "12"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pi1", ",", "diline1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869226794027348*^9, 3.869226935888006*^9}, {
  3.869231793805572*^9, 3.869231794582507*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"94df5fd3-8698-4aa0-85ce-cd8b7064e196"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923k8VF0fAHDG2BmzWcYwZsbWIlGpkO5JpdKmfVE97fsTSlJIJO1oU0pK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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 3}, {0, 12}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"I\\\\\\\\,\\\\\\\\rm{(deg.)}\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{4, 
       FormBox["4", TraditionalForm]}, {8, 
       FormBox["8", TraditionalForm]}, {12, 
       FormBox["12", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {3., 12.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.869226936278295*^9, 3.869231474205035*^9, 
  3.869231797773621*^9, 3.869231857778613*^9, 3.869231992828389*^9, 
  3.869232054220809*^9, 3.8909779231507273`*^9, 3.8909779599992743`*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"9bde6f18-d47b-4227-9364-390aad2578a9"]
}, Open  ]],

Cell["Plot the inclination of Venus.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8d5610ee-0466-446e-b5e5-b8b94e227c29"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pi2", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "ivenu"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "iylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "2", ",", "4"}], "}"}], ",", "None"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diline2", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "5"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pi2", ",", "diline2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869226969091948*^9, 3.8692270312673483`*^9}, {
  3.869227149919794*^9, 3.869227195682585*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"583b62eb-1acf-4fc4-ae99-d1320861cb0f"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m2VYVUsXgE93H+wgDExsbGfETrALxcJEQQUTFRVsUewOxMBuRWIPitdW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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 5}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"I\\\\\\\\,\\\\\\\\rm{(deg.)}\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0., 5.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.869227037371491*^9, {3.8692271503064613`*^9, 3.869227197119738*^9}, 
   3.86923147429991*^9, 3.869231857865445*^9, 3.869231992923174*^9, 
   3.869232054404228*^9, 3.89097792319705*^9, 3.890977960174589*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"b31e0638-2638-46ed-b3ab-307d0c26a48e"]
}, Open  ]],

Cell["Plot the inclination of Earth.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2a9847ec-469d-46aa-805a-e6a11cbc8bd2"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pi3", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "ieart"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "iylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "2", ",", "4"}], "}"}], ",", "None"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diline3", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "5"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pi3", ",", "diline3"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869227073671453*^9, 3.869227091259994*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"5c2c5f4d-6e70-45e8-8257-7c333ec1c64e"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3dczd8fx++e3dsd2Vuy987oHJtIZCVZyQgR2SIrisjeIiIhKnv1OSoy
ipCU0dLe47br9ru/+3mfb/94eFSf7uc8z/N13ud83p9OTuvtlvM4HE4en8P5
/7/slxk5dTVo3rd2QlzV3dEvslJLCifOCXh2rBoVznzW3qtAS3qMtmGmtMxE
6TvM7k9K15LKfc/fCj9Wop833EbLfmpJbwvHqNEfuDgu9v9fWuIzokWs2FeI
oyr/f0EtcXhhd6BFbyH+/9VmPtOSMbzU6asfcrDhYoYraonln+8Lk3rpUOD/
L3dDS470dJkd/LwcXbzw/y8tYZ5Odv3iw8GGD2e4oJasXrF/esM2Ef7/1dp7
acnMM46ZgZFivPP/H2+Hlqw8/rfLQk8+3vD/y7lpSdXcVuhRiQ6tMH5pyfyB
M25f75CIHI0X1JKu4gfhjw40IDvjB9SST/keuyyWSvBk4w0bfv7WndgyfyU2
Xm60lvi3PHttiUqFBxm/tGRcQv2663UmuIfxglryPK06SVQmxB2MH9AwPqMj
+2f9qUHGj2emJe3GBLy63zIbGS8n05L9t7/eSD5ci1geWtJrTcAnCxPKQ0M0
u0/9nOArxSwPDVGkye0G6SSY5aEhzq6dVpxy4WOWh4ZY/YyK1TdUIpaHhmw+
c1y8Z2wJYnloyL+vw+x7ezYiloeGBHZ3br5nrgB4aMj625+2t7cUYpaHhrRp
bjdEZMLFLA8NWZncLCsxpgyxPDSk48K8l0PK3yKWh4ZcjVF6repdjVgeGmJf
3GnKJI4AeGjIh8Q7E09OlWKWh4ZY9GyjibktwywPDWmVUjJ1KiPGLA8NaXh+
cuXcjxzgoSGryzy49zoXIpaHhjxLyElbdzYPsTw0JPXn17XdgjjAQ0O6WMb1
8W4mAR4acqD5uc1mG2SY5aEhdl7dAgfwxZjlYfj7w8asvtupEXhoyNMnke9u
jE1GLA812fXX1/OQVRn4oSYOK0YcLeHygIeazN/o+qPbcDHwUJPbjiEpeSfE
4IeaqCwDRsYf5mPj8EWqyYES/5c3JbXAQ00OLuf0XbYpC7E8DD9f0Y9z+0Qp
+KEmd/ua5pQPbAI/1MR8oNm7jCwB+KEmVaqo/R+OUT/UpPL1Ws8FH/ngh5qk
Oh/167KvFrE81ERWv/vu7+GJ4IeaNL8wefLd9aXgh5qsnei8OmgCF3ioicR/
fy/tBBHwUJOvb5M+9i0Xgh9q4hPKq/XfwwE/1OTmhl0ps+JKEMtDTa75uFQL
1+YjloeadCyNeEzO6cEPNQmxWeS/qa0IeKjJKsWtoc37SjHLQ01y2w2Nz5kr
AT9U5O2InH2aYQLwQ0WszsRZr2iqh7xSkQyO64JmqaWQVyqSX+aqPyTUgR8q
4nkVN2+Z04RYHirys3FNeaCVAPJKRSJf2HfpHEb9UJG4RtXppU844IeKuE2I
UJOdNK9UZLB7yJ6N5mngh4pYz/gw6NqEKvBDRbKrItPfVnKAh4p4lZya4j6Z
B36oyIGQA9bf5jYCDxXJDU8f/yu0CHioyMm2zgOPGPKD5aEinMgNc1c2NiCW
h4p0KD5VvtpTBDxU5EjM3J+9tsqBh4r4tJzh8CuC5pXh806ZKBHaysAPFRE1
HH5zJEQAfqhIcfsxa9oMqYe8Mvy9kpute/esAj9UJEzWf2T2SC6Mvyn5sSiz
Pc9WAvPflHT/1b76VpIc5rspsd545UP0OBmMpymxf2JR1fkxH/LFlNxpNXxe
/y8VMF6G7/cnE/I3piLjcLuZErfRX7v77quG8TAlx1xIH6zmwnw0JYKlMx9N
OMiF+zUlokeL0zhudciIs70p8fp6LWXDjiy4H1PCD7mjXLg/HfxWkjRzrkO7
Qjp/lETEO3cppkCIjdMlVkncZ3q39y+WwfxQkm0DQ/v5NMlhPijJmKHd/Nuc
luDjxhtWEueZvuUzyyhvJWl8Y/ln88gi4KskwWeqc+5urACeStIpzGJafBcB
tjJ+QCU5JTw+kjklB15K8vOX5/sHjxTAR0k+HVxnaSeVgR9KYrM/PNkmgPJQ
kMk43XqxeSHMfwVR3299bH1MLsx3BWm7y7VhxfUGyBsFEWmu9qos5QEPBVn+
YEXoKBEf8kRBVrwKGB7wuhF4KMj67+ne5SOLgYeCCIOxUL7/F8xHBalctfpw
46cayGcFkXp/tT/0UYBZHgri1tcncr9aBr4riGLP7ks9n8nAbxNicswvYV4L
EeSrCVmcl/ojZGstYnmYkJOxa78vfv8S8tOEmJr2sZtwqwby0oQ8tXXo5rBP
BDxMyKS4AzO7VcuBh+H6unwsuSiH9ciE2Py1nplMhJB3JmT2nOLhaVXViOVh
Qr4fLHFuTHkKeWZC+AMmdPkSoYP8MiFpRys8HT7xgIcJ2ZqaFl98Tgw85ORQ
5wlu0/tTP+RkzakzJb29BOCHnHgll+ZzO9UBDzmxXtKhjNs+CfJFTuTT1ixY
urwU/JCTGREX4r+kcjHLQ26oF64NGCCTwHoqJw5bh4xa2UsKfsjJHxN8waZS
AH7IyfDCOc6pLWvBDzlxrW3L6bXsL/ghJ9ptVwfuXV8BfsjIm4m3b38r4AAP
GdFVak55FvHBDxnpG8gMfjCEB37IyOZ4x8+DiigPGRm931J76WQaYnnIiLzC
ZLrjtSyoF2SEazWufNKKBvBDRmLXimZVdqQ8ZOSTJLJ8XLUE/JCRIRmpYSXv
JeCHjPS2ufouYRzNLxmJKlxL6tfWQF7JSMLDwsyYK9mwfkvJk4Gu9rP9asEP
KQk8/n7GITMh8JCSByG9s1oulUJeScnj0rBWsq0S8ENKFi1ZFXf3BQ/8kJJW
He7FycMrwA8pqZt/Zda52W/BDymR3Xx2KSC0FPyQEq3FhAyPkDrwQ0r8lAs/
F/1oAB5Ssioup7uHRzXwMPz+WPd/1SG5wENCAk5dbfZ92w/IKwmx67b+2aBW
leCHhIS+PhiD3CgPCenh/ebkrokSyCsJOSM5cDHOWwZ+SEhVSUJJoiG/WR4S
MnETcZvH4YEfhv97dXiwIbsS8kpC9L/l6fqUWvBDQuoazbdWjRUCDwlZm5Xh
vneTHHhIiFlxHy36ZQJ+SMi/lx/aubSXYuPwFYjJ4FYHp0Sv54IfYjI308FM
36IU8kpMjpYPvFW+7A/4ISZbVpz4e2tYBfghJncXxs5wTagDP8Rk1E3H3U5b
6qHeEZNLSwU3Y1wqgYeYROxZ3CxrWSbwEJNi1VTRdGE68BCTDZM6tZjvWgP1
ipikmN/cWLKED3klJnsmdX+TuFkMeSUi1j0al6Q20LwSEZ894oQF/nR/JCJe
G5YvmZZYBnklIk5tpmcfayoGP0Tku4z7kBfChXpORFJNNsmuv5UCDxGZ+Sfg
2KD+CuAhIgG/eJ6mY+Tgh4i8Dh6+3v+ZANZ/EbEM9Bumj6uCvBKRLu6+7t3+
/Ya8EpHbselumZsrwA8RWTbhrc8JQ/3G8hCSFtXlEdFSAfAQEj/7i3UbL9L6
VUgGJVycGNVaDzyEZMr4gwWOhvXGiOOCkFjcfvbi0dp04CEktf7bYlJqGoCH
kKSts0occUUEeSUkv/cFL78+XgZ5JSScHUeQeKwE8kpIPgqfpjt/50C9IiRt
l3slZ7+i+ykhmTFwz+vTpBD8EJBis60WbTrR+lxAFnXpM9HaSQo8BOTze6+X
Ybfk4IeAnJ+hKM9Jpn4IyK3u+jVnUigPAalr3q73gHWlkFcC4h9x4p3O9i/k
lYDwBkur+YPqwQ8BGfDAfkvQM1ofC4hFmMTvrmG9ZnkISO4Qt8bAhVLwQ0Cc
7Pd91qzngx8C8it0vHu7WeWI5cEnh2WJT5bb/4a84pOi3qbPH4hp/con1kxn
/lJXCeQVnyx+11y1qKch9I1ffHKv2QWnaQoZ5BWfqAPm+337Q+tPw8//eZ8y
pE0Z+MEniVHnwp+nJoEffLK5a83Raa/oes4nivE3nTxv8YAHn/C76Xfu/SIA
P/hkV4cLAucgHvjBI42r5z2p7FsLecUjLRTSVz8WpkI9ziNTh/b7unVnCfjB
Iw1bYt7rmrjAg0c6XebbtzolBR48Eh1mHd1tjwn4wSOjUi8PXvyQ7i95ZHuv
nX16HKb7Fx6ZMnxzjsq0APaPPKIPC+t0/osO/OCRXzN9dh+/KAQePPIpVqhF
SAE8eGS5anHGhWOm4AeXTPr3qtZ/uwn4wSU25mMGvu5D1w8uSZx3/v6rydXg
B5fUn1SmVq5LBT+45NftZuZtPpeDH1yiudJj3Mc1TeAHlzxyCQlKeskDP7jk
rHx1YvNgWu9yyYqB3ut+aGuBB5e0nDJMw+uaBXnFJbJAi9gSVRn4Yfj5c62C
RRu4wINDbOevW2N7Vgx+cIioSPDlbZIE/OCQ4/cc+ga/pPshDum/Kkj2x6YW
8opDBv56ETL+ZhHsdzhkRMKNm/fzG8EPDuEdyjC/5SkGHhxyLyh/+Mq9JsCD
Q7hXOv++2loBfnCIWN8wI/uBFPzgkB7CDrOfLuIDDw65WpEoGnS7GvKKQ3z9
c8aH4kKUaBz/JkY8eo3POUO+s+PdxIzJjRZGME3ogHF8m5gYl9Tjp4bT8Wxi
HO/ZdMg+xMEDjePXxKzt03Z4zPAqGK8mJrlDu+n587NQmnF89Mwm9/XfOfMr
YH7qmcyhrQ45OHFg/dQzs1J9AtKC+HC/euaSS/VU+x48qFf0DP/O2NjKKHoe
pGfip1zw8+iXA/VIIzNpuc3MqTY68LmRydWfeuhiR+vxRsbMOcpqRScJ1HuN
zOKdOdu3LaR52chMblps/rNIAvV1I/NiT9vm32YJgHcDk1XRy7WtbT3UBw2M
buC/zMfb6flCA2N2eHj9mogqZLzdHQ3M4Us/hHdNecCrgdmXtWley5UibLxc
9wamzMopYvssEfjRwJg3c6hZ5MjFLI96xjvvKErILwUe9cy+TaOH9pnyA3jU
M913SEsFnWohb+qZ7JPJ8yzc+MCjnjnQJerMpuNCyJN6RvEqVXrGkDcsjzrm
3brHB8qWVQOPOuab5f3zPo+SoL6sY1TuEUMeSksgn+uYr9Wz7761boJ6pY55
tvDW1+GptF6sY3yX+Q20vSCCer2WCY4U/vi+k9bntYzrzOSyvuMaod6oZcQH
mqofNc+Beq+WWT3q+6ji/v8gL2uZf0OjNu50aYR6zvB//6zZt37Q870axmNx
QM3GKRKon2sYcm1YzvuR9Pythvn9vGvYiw11wKOG2cpzuvlt/FdYX2qYMZ+S
WqVtqkAsjxrmzvuLR3860fWjhjE5/G6JmCMFHtVMkMPUR/w7tJ6tZo65bRZm
Bwoxy6Oa+Tol+oDvgAbgUc24+ez4PeN1BmJ5VDO6Hst8N7+k++dqxumDy0Oz
b/XgRxVzL9rV2uUdH/KiinF2t7C1jRWCH1VMeL+wimJH6kcV41tp9fx+Gq0f
q5jtYY8SP9Xmgh9VzOgbdevdS6rAj0qG3z9wRJsKWn9UMtYfeo4rzaL1eCUz
JnFBkcqN+lHJtO81Y4liLQ/8qGRy5/nZd91dCjwqmcP3wnY19M2EekHHlKxZ
0e2pLwd46JiVxbfrt96VAg8dY2l/FVc8UGKWh44ZO2jst61KU/BDx8yKC48Y
xpODHzrG7JqbXXt7ykPHzLHLnh7WtQLyqoLZnfw4y29cNvhRwdTtHTOj6UUD
+FHBDGkUF2ifCyGvKhiR2ZNcm3cS8MPw+5s+f7z8kZ6XVTDzWv+VRoZwwI9y
xtlW6Degtw78KGfEZQPmND9WBX6UM0q3ky1etOMCj3LG0TmFe2UkPX8oZy75
LRT9DuSBH+VMVP/pT4Z3qAUeZcyTdUtyRo/8C3lVxnQMXfnjx6Ji8KOMIdKN
bWyn0v1pGePXYXXitDR6vl7GdHpSVT60iwLyqoyZ3+BuNcRRAX6UMpoPyfIJ
k6TAo5Sp6nqhk7cTrQdKGS+HmKvf1pSAH6WMa7adl+vKMvCjlPm7Nm/jk1gu
8ChlCj+tOVnSKAYepczZnPKU4FZSHGoc/xIm+1/r2EmFAmxvHO8S5lXwabMr
z2uRxDi+JcyyE2OQZ/9MGM9iZuzEs1XjL5ejVcbxK2Z+Nrd61vGzHqmM41XM
5JsvNL3ymIuJcXyKmMejTbIqDjRBXhQx108f7mpOdKij8f6LmHOXBzk8+Z2G
4o33W8jwU8/uX5hbirYZ76+Qabuz34e3VzhwP4VMpE3/kNX2YpxknE8FzLGU
lWde6WXYmy1QmO0Nad4u62W4v3G+FDA+Z7KtKhYIYX7kM+aP3n8QZdXCfMhn
OlSXrDqnK0LshMpn9Gsqpa3bNKJc4+XymNVRe/84zhPh80a+ecyujw+nChPo
+UIe89q12RxNrhjXGD9gLrOrvI0dbzAXXzPecC5jZxW58tzLYjTDOIC5jK5B
EWdxJAXW81zGRmRp3figGrE8chh+i4z8p+Zc4JHDnAzpZ/LyOg+zPHKYDi+s
nw7cyYG8yWaGzb1k2Ty6CnhkM/Pfei4+vv0f8Mhm/kZuXFHVIw+xPLIYydU+
cy8G1gOPLCZi5P6Zumd8zPLIYsjWG4saGoT4vZFHJhN/ZX1l0wU+ZnlkMtbF
Mzri9bWQv5mMfem9xJfvfyKWxz9mwPiYtnMeliKWxz/G/+9Zl6ARXODxj/ng
bet+UysCHhmM0NvsxJmXNC8zmCblzaZLWzmY5ZHBWPVemjekugR4pDOznuV4
3nT8h1ge6Yz/iIu3ma91sP6kMz292isKvATAI43pX66/tX2BBHikMfzrGaFF
qyWY5ZHG2Pbp2G/aCwH4kcZsLR7Y+3NsPVpiHP9Uxmpjxg3fyHwUahzvFOZU
0e4fo4/pYHxTmKQgj4Uvv/HA97/MuqN7Jt0KlWB2Pv9hJJ2D2tU/luKOxvH6
w2ys3/wqxV6I9xjH5zdzbzvn6pJ+tbCe/GIyV844tjfiJ8zHXwx+kVLuOE+H
jhvvN5mJ9rEtnvKXi0uN95fEPMo8GtCtUQD3k8TkdT3xIEnHA79/Mu2rU/oU
VdYgFVuwMz9WnelT2uM3WmKcL4nM8uKr+V0DSmB+/GCidl7pPfkJF+bDD2Z2
uF/TSxcp3mPkn8AURMTMcb6pwPHGy31nPISb0xavUwDf78wIJ6QrW0XPg78x
Hn8en6y6p0elRn5fmZQms9/fvPIRW4B/ZUYf3HlhX3wdYvnEM1/wpTmxu2le
xTO75SOaHE4pMDGO/2dmocRPG1OlwEuM4x3HSKJMzqO3EhjfWKZWv7Dw4YQm
GM+PzOGQdkMse+Sia8bx+8CMu+n5ckFQCWIFes/47P5+9e/ZBsQxjk8ME7ZX
/vlhIwfy6y0zaVl0zzR/PWLvP5qRvery/fTJCtTReL9RjEno9Iwuf36gNOP9
vWEWfCHj+msr4H4Ic+t1s3yPQXz4/BHMx3HvW2mTZZhd4F4xMSte9w/xUuI9
xs/3nGk5o0fp82ITzH6ep0wLmzc5bYqFMP6PmNNdL02vGFiFOMbAD2OaFce/
3r2/EO0xXv8+s3h37bOm2Ty4XjBzSLdjef5tOfx+IOM703LpnS+mmGPcMPkz
TwXqhUNVSswxfv80s1uw5XTGYDH8/wCTGBzzr3nfOrr/4Iw9nxIa/usLgu+j
cOfO687llSBOM+PvoylbKuLCNuoRXB996FWr70l49O+jVOdA3zst//t8yM73
htY2tA5+/j7a9NJS+ao+i94fWr3gXshRZR6M/yOUMLa9wK8rh44Pmv+nOaek
QIwJO36ofedNu6KxnI4v+ote8dbKpHT80d2r2vq/V2g+E/TIy8r988hCyg8d
DXq+oMNcw3rA8kXjHp5N/rOLC58/Gp26e+j9rcUSOj/Qjrkzu3i6y+DzxCAH
/x2THIgYL2HnF1q6TB+snW74e+z8Q3Xmswo/byyj8xMlXhga+WJ5IoL5i86m
LpGsctChPez8Rn+1DivzbnPo/Edrfw4bqiyk9VU82tiif2hnGR/uJx5dbh0Y
OfFpPZrB+oXsJtrOiqvOpP4Z9v2S2NYTM2H9+4Y6be2fspLbiMBfNDXY3mJf
rACnsX6jyB8ftSvsRdR/lDDj8xu7TzyaDyhqeI8+X22raH6gXtUWyx7GxyI3
Nl/Q3XiLbamHS2n+oEnN/nofj9bDevcTlV5XBtwv4NH8Qn8KkrvoDvNovqFO
/Vupxrk2gr/JSN6n8c6+2lKajygsY2DwdUkazU/067ztiPgfhvFj8xVduTop
52ueYf1h8xeRFvvP3agX0XxGI3MWtBglpfXzX+Qc/r1nm5UCDPmOnM7VLnR+
XIvY8U9BD34ru665lkfXB3Rg7Bgy6BvtZ0hDK6ZYfH5kKaTrC5rHDy+MCJfi
2+z6g57uWv9thUZK1yd0740880IEH+qJdPTJpZ3Dg6Aqur6hnOjpW53+JgC/
dLRqwrTtSWaFcP8ZqOjBtKTBDrSeyUBhy70TG1rpYTwykCrpyPmphvVsOLv+
oor8Jb3sysrp+oyK6ze2X9iUQNdv1FBwcmzJ33y6vqNOTlNcBZF6qMcy0aVh
H8w+t6Djl4m+FDj8OFEiofUDcqs9vaL3exGMZxZ6c2Tb5N3hTbT+QMK25X3j
OhSilmx9goLvKVSt+lTS+gXVV0ydGX+Cnr9ko63Fm+b5HZLT+gc5TQl0G+Br
yH+2PkKjJjUbcWiLDNa7HKT5bt+5zXzqRy46N36Axwe5jtZfaPaygwUnUBxi
eeSiBU8fKsIkZQjqN9R7/nwrtS99vpyHmo9KXXkjgEPrP3RA0jviyVi6nuWh
McFeW+0362j9iGymDnvm8CCX1pdous7Fv831GuCRjwYO7N8/7L4AszwKkNa2
7Xde+//qVxQ78Pqu1EMyWt+is7fH9M011K9Q/6KcxF4HDx6vpvUxcrc7snLi
gGxaPyOTdNPSM++aaH2NpgkDxrz8LAUeRWi6aZ1unbcprc/Run19q1PNVJjl
UYy2B31SvG6QY6jvUbM3vVWZzSmPYnQn9tfIEUN0dH+ADg32TFJcTAMfStCg
cYI2tdJa8LsEhaO9T4oTKI9SlFrgk7jeXEz3J+hEny8TbuwX4tns/gV9mjdk
dtATPfJg9zdowLrSyx1MSuC8phRtjpsztjFNB+c5pehtcElCywQe+FSKtveY
7R9vTudjGTJrlvJl/6j/9l8o6frd809qab1Whs722BB6f3IFuszu39C0B8/c
taKvKJrd36HWRzmx7Y/8t/9DEd10Tdmz6XlpOTpf0umLh6UM6lXD/wVPUuXf
ZTB+5Ugpsxia3VIM9VA58kmY9tpN3UT3p6jVLPGPRyp63laO+jg/PxYWn4dM
2P0tqslfstP3BQcPZve/qE1y4ACPB2K6P0YFac8bNx2WwnlGBRqFNuzUhgjB
hwo0wfZV6esPteB3BUp6Ue/t0OsT5JUO1fks9GpzphJ816GeUvWm+0oB8NCh
i/kfJL1TJZjloUPbG6sWe+2mzwt06Er48hTTzfR5qA59WXiTKT1QBT7pUOrW
8ebm15JgPlaiJ8eVqQp5OfhViZyPuR79bPALzi9Q3Ve/EeJVQszyqES/bX6h
86NFmOVh+L7vfo+Xl3lwXlWJPE8OTG55q5Ken6BRd93N3vQJBx+r0IRdZZfn
TaH7I0PdZFXT6fIOAT2fQdaPxnWe4Sel5zdIP/eC76nmUtifVCFBsWnr9PF8
zPKoRotKHzS3PaRDLI9qFD9qsGZ2F9oPUI1y6t3dnVpz6PkS2uuE3F1dxcCj
GvWtjWoXH0v9rkYX3Cx3Tyik/T41qET3z956G/W9Bu27ZLPlo00jYnnUoEjv
gn1dxxWDH4Zc8e4zzfJqIfhRgy7jw7EWubRfoAaVlxVP9erLBT9qkPe1wZ4r
b9H6vhY56mIFJk/q6fkdiuk8zP14egE930O5ky6aiY7ngB+1qFXYlpdX99eD
H7VoQSLJkBzn0/NDNFkwQVOd8d/5Iorj/j610IELftShKMHSJ+ndaN7XoaSe
+5NutCmh55coo12mV10J7derQ5d2vLs96xzdL9ahMfhAw287OfCoR6Inaxwt
l5mAH/XIA9d2npMiBT/qUcXtLenmjgLgUY/eTuYrd66rg3yqR74j4/pV3S0D
P+rRhIOd+nzqR+vdBlTmeGfd4B58ev6LNLkXFnbtIAI/GtD0m6fxZTcB+GHY
R9jZuU0Ja6Dny6j5+t+Fh7bl0fNntK5n6vJmvUrBjwbUKfVEs46NevCjEYU6
5J6+cJrWA43oQthYmy+faF41IscVT6s/59UBj0bUmDyfGTMyB3g0omHPmhVV
LCuh5+uo26SEIQd+cICHHlUlWJcNGyMBHnrkmCny3eVnAnmlR/unPb+UxFXQ
832ka6uz4M+kfuhR8Tyff0lpXOChR8sHqCslhhxleTQhz0kWrhful4EfTcis
kXvhdT2XPn9Ap6JXH574XgI8DD/f9cyeXZfo+t2EDs7UvgktEYEfTchtc809
9Qfan8jB0q5DAh+W5oDvHJyg8hh0SVaOerLPT7DvpWOHDozkwHkeB+9ZY9Pm
MMOnz1/wPe79FQMC6PN9Dh6Ub5Ex9WEd+MTBF3e1Gf7uJK2POThq6gCzvLEZ
9PkPfhH6U5tbXQ/zk4PnR3ee3fGGEH9mnx/hDiV7fwXopTiDfb6EO6Ym2aoN
8xGeP2HuxTu+yg/0eSEX//k4L2za/Srgz8XhaYn6wpqnMH5cHJYcc56XWgt+
cnGK999DSTvp82MufigoWW3TXw7zg4tX5VbPFfFl+CD7fA3rdzEt7RxpvxkX
n33/zIObVEafz2Hf+D2fXeyT4DzT8P/uA6LvHKoHH7i4LnJQXuNRIfjNxVmp
38tejKB5xcMBEb8eXd4koc8P8aiHgy3OHORjlgcPX11xaFLDpio47+Zh8xQH
n5+7ouC8koenZMwPrepH+5V5eCJ28VjclQ8+8fDFqDnbW3nQ8wQenm/aMXzx
C7r+8LCFy8HAc4/o+TsPpy8ek+4ZUIlYHjy8f2yvcyFV/xDLg4eDLv4W1e+o
g/NvHm48Ocp2htN/z2/xjk8hHodzRJCPfMzMmeDVaYoA8oWPzT5Ocfnzmp43
8XGHZj3+4cNp9Pkx3ihxbF+eXwj5yce2LfHn9F0c4MHHWZ8dbo3YLwYefOzd
55VsVgc5fX6ND91o2zvlogzO+/n4j/XBDQ7vheADH7eetXvYlet14Dcfj6g+
krK7MRX8EGC7w3fcPryuAD8E+O6D8F1ujjzgIcAK1+kPvn4TgR8CHF4S2Bf1
EoEfAmy9MGT77iwO+CHA5lHfasf6lIMfAlzVu8ihqV0++GH4e7szbh5sRfud
BDhSWD9V0ZaeTwpwX01Y2MmFHPBDgO8LvO8M+FILPAS4Llb/JMrrv/4FfDLD
ve3kQTm0vwFP27d62/s1deCHEE9/sqHvvOZC4GHYZ9mNW9Ku4L/+CZwyYVVg
Zj8F7a/AputU6FSDDPww1BUXV9167SUAHkLMWTm3svmEGji/F+L2EcXZlqb0
eaoQHyifOkKi4NH+D8O8HLU8brkEeAhx8p8XX0SdZeCHEEdMiDmyhqHPB0V4
wLUJ/WyCaL+vCP8IKrjq+yYH8kqEp7dw+JcYnAx+iPDSGzdvF+tof6QIa26a
3L4RWwd+iLDfndZjXefSvBJh0ejDAWMnVQAPET6zyiNgnFMK7a/BA+M8rtX9
yKL9NzgzNjVm7uZ68EOEe21o+nDdRAh5JcJ5278v4a+jeSXCNq2HPS5yldL+
Hxy48uYaWYAA/BBjJvNu/6RzNZBXYvxp6OyrgycW0f4i3FQZ3afekN/Qf4T5
vQMCTV6J8Ea2PwkHTLe3VtnQvBJjbaj2bGYQfb4lxpyesWSkOw/8EGPf+Qcf
vI4vp/1R+Kl4iOtpVTTklRjzTPndzKeUgx9iPNWuy23fHnrwQ4IL28yse3OJ
S/uzsM2kxpJFS+nzBQkeG+m6tqHcUEey/V142Po4q6Ks31B/SXDyHM41b6s8
qF8k2Hno/G+bdE3AQ4JfedrFiTCt9yV4VllO4TzD/ID+M9zrqaX45jEx7U/D
8aY7RiRca6L9a/imDmss7P/BfkCCl8w7rf6ZSOsFCf7IjLt2+zcP6h8pvhrc
evAoJynwMNStx681zwuTgR9SHFp8/PfA37R/XYp5PWu6tTXR0/48nDCk8vK4
AVm0fw8/9mj/coi4EJ7HSfGKx2dvSB3p/leKLafvb5ezkNazUnxkZ5nqyn4Z
1OdSHO65z2NzNvVDinOPtjRd6ELrdSn2WW35W6Uopf2J2PHNnlRvwT/wQ4bH
7hu3o+diykOGyy92rV0SJ8EsDxkueOizv6BJDvWXDG///S8wdJYU6hfD9UJD
d54N4sL6IcOvzKPuZ/coov2XeNwKsv11UDbtz8TLO9lz511tAD9keE6r0ZqJ
r/7r78RmjtlFyx8KoN6RYdN/95vrRtJ6WobXpge5Wmp1UP/IscS/OvPk8ieQ
V3I8rvWWBeYzK8EPOf73bemdj3cFtD8Vzz9+Fjt/ktP+Vdz7YHrKPUsl7W/F
5vqbfoM5cqiX5Dj16vUrNwzrIstDjnfNmb53TlMB1LNyfL40cdeZ8+VQD8rx
jrzNHSrOCICHHJdMDQrb1d6E9uficy2D1pq1U0JemeAt81JeWx2i74uY4Gjv
i/NWXeMBDxOsOpL0q6ikFPwwwd8P6wanJX8DP0ywT9can3YTaX1vgodP3n96
RXsO8DDBBTL189xwLu1PxuHzmkmWC/W0fxmXLw8ICbhdSvub8ZrAvOmf936n
/c/4lWbpKa8I+rzEBH/i5ChnvxABDxO826dNxGW5AvxQ4HMRtXGFpkrwQ4H7
rH7zbICDFPxQ4EW21pJNtvR9GwXm+zVt6jeR9oMpsFY60jmo13/933jw/FUy
vyAx8FDgaotdLyZ2VsB+VYGXy0cdXxqjAD8UeKfd3nB+uRT8UODKQOnWuiQe
8FDgvnHCPkuG6CCvFHju3j3f5hxLBj+U2NklO2BzxzLwQ4lXJa7ZOrZvA+zX
lXiRMnyCVX8O+KHEQWNaXqkY1gA8lLh/qvWqwLBS4KHECrI67PrkDMgrJf5q
5fuw69Ia8EOJr8XO9D/tz6f9/fjgmZOl3RDNKyWuGPPiZ+6//94PwAu2tArz
q6HPW5TYLKBhq81xmldK/NNibGakuBz8MMUT75xSL0jhAA9TvEQ26uTdLBHw
MMW2BzO+RI+nz1dNsfpp0L0tCfS8wxSnjunruLY7H/wwxZNfjkrwPV0DeWWK
nUMld7rPp/tVU1xmM/WsfHIZ+GGKx6mD5gVt0YMfptjlfnsbfzs+8DDFuteD
fnXqTvezpnj+lC9b9txuoO9/4DVB0S3mFtH+SxW+kidqafIhA/io8LQm/Xr3
M7SfWYU7F/frxXkkgPpLhX/sPqnftojerworjyW3SzfUnez6r8JV+mcVQ5hq
+n4LPmYfGV2xMZ2+/4Lf3f82tohfTt+PwTlRqjsNE2m9psLBF7ctefZdAOOj
wkdfBHu7/haCfypsVR7czBPzYb1V4af9nxycbqgnWf4qvK3sm/dXx0z6fg8e
uTre/lxYLvipwuHhbRuWe9P+VxXemBbulFdI33dUYa/rqz9IO0ugXlLhTeMc
baJEdH+kwr/EU0YsHlAH67UKb1h5Zua06d+hHlTh+VaWglXbKsAHFR5eEePu
249P33/Cf0M2T+t0TAJ5pcZrez0/cy9fQt+fwkqO3tvzEj1/UGPRyw7PR6fQ
fn81frTyVWAfx79Qf6mxt9y82ZaQLMhnNQ52+Xt3RzDtz1Fj+4KqL25LaP+h
GrfrUvPy/EDaH6bGlS+Db/pn0fpGja3CTwx69ayUvl+GnY4ld9SGZkN+qPHd
tXNGPf/eAP6p8Tm781Y4VAQ81LhP56wVHStpf7oa2028Y27xXAr1kBrHdx13
LlnPAz/VeP3akwVZGrqfU+PhqXO6b8UF9P06vC2xVb9P1Vz6/h3u2W5VzZPH
MuChxqELIjeE1ylh/qux77kXyvK5SqgH1bi7e3cf7nT6PqYaR0gHf35UxwEe
ajyC3F1ldriAvj+IW949Z/PRMwP80ODjHl9Sivn14IcGnxl8Z9nJY3zof9Hg
odEDTs0eLAQ/NLjqY6RC3ZYHfmgw78soUedA+j6KBiv3Ol+/6kHPDzX4VWvm
ZcCnJvBDg6eU+b1uF0X3x4bfX/Ssx7J9/71/ifcM8F6/sow+n9DgpCtjXKtH
0/pNg8NX2pmfXpKLWB4aLF1iu7bFvTLwQ4OPWOtDFvyh/Yka7Jrqwr96nNZ3
GuxU92K03R4lfb8UDxyRW93JQgl+aPDa9neKexrqKpaHBjPfeg9VWHKBhwZf
vhWTMet9Pvihwd2LQipSZueAHxo8qs3cA2036sEPDa77FRzsa/7f+7M4JDE5
f6WQ7j+0OGf2rOfOeVzwQ4svdg5KSnlBz0u1eLj9scDF7rQ/TIunHHOLc45o
AD+0+PoI25GHvvOBh+H7icOy+UgIeaXFxd4FXSwG0X4zLa5obj3CaXk1fb8Y
bxgT8zsrLpO+f4yrdkwcfyq2gr6fbKjnRd2uj6TnW1p8z2t47eI4et6sNayz
g5wGK03ADy2OcgkcWyGWgx9avKn3w707dgmBhxaTs/e+vHlD96NaPGPdjPWB
7pnghxZ/mrHh81BpHfihxSEF9S869Kf9y1qc4hI0sfGdBHho8c150Rb3PtDz
KC3uMPn9u5r7TcBDi+PNB3EcV9N+VsP4CGZkzehH++u0OJHrem/qg3rwwwy/
kZU9ixrDx/8DZSIexA==
       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 5}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"I\\\\\\\\,\\\\\\\\rm{(deg.)}\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0., 5.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.869227116077263*^9, 3.869227210045692*^9, 
  3.869231474393668*^9, 3.8692318579718847`*^9, 3.869231993016528*^9, 
  3.869232054455782*^9, 3.890977923343931*^9, 3.8909779602408247`*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"c771e40f-2958-46e4-a6c6-1ee23b33148d"]
}, Open  ]],

Cell["Plot the inclination of Mars.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0bfde1ef-9843-4674-9f61-7f57cae4ae74"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pi4", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "imars"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "8"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "iylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "4", ",", "8"}], "}"}], ",", "None"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diline4", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pi4", ",", "diline4"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869227233736532*^9, 3.869227287766323*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"ff3199a1-5f59-49fa-ac0f-8421704f1975"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3dczd8fx+/e+96WQkZZ2SMJ52STlU0oOyGJkJUVZc8IWVnZe8Y5ZG+R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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 8}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"I\\\\\\\\,\\\\\\\\rm{(deg.)}\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}, {8, 
       FormBox["8", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0., 8.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.869227296231926*^9, 3.869231474514057*^9, 
  3.8692318580581408`*^9, 3.8692319931108027`*^9, 3.869232054506372*^9, 
  3.890977923395069*^9, 3.890977960307479*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"7297f65c-d028-478d-96aa-05e1aed4e734"]
}, Open  ]],

Cell["Plot the inclination of Jupiter.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8bcb66c7-6f9a-46f8-b48b-bdccb4939579"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pi5", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "ijupi"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2.25"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "iylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1.5", ",", "2"}], "}"}], ",", "None"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diline5", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "2.25"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pi5", ",", "diline5"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8692273291678953`*^9, 3.869227434825968*^9}, {
  3.869231817744658*^9, 3.869231818178051*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"13263199-57c1-453e-a82c-f6c5b0b49c38"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923dcjd8fAPDbHrdxR4nMrCSyt5wjq5RRhFL2li2URMTP3snOKlkhI9+i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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 1}, {0, 2.25}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"I\\\\\\\\,\\\\\\\\rm{(deg.)}\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{1, 
       FormBox["1", TraditionalForm]}, {1.5, 
       FormBox["1.5`", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {1., 2.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.869227413636726*^9, 3.869227437973998*^9}, 
   3.869231474607053*^9, {3.86923181899153*^9, 3.869231826298202*^9}, 
   3.8692318662672358`*^9, 3.8692319932272053`*^9, 3.8692320545585012`*^9, 
   3.890977923444807*^9, 3.890977960368284*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"57ca1787-fd3a-46f2-a29f-dfe7e778594a"]
}, Open  ]],

Cell["Plot the inclination of Saturn.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"75b70071-0bec-42bd-9249-1464b7b15e51"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pi6", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "isatu"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "iylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", "None"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diline6", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "3"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pi6", ",", "diline6"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869227464436921*^9, 3.869227531230797*^9}, {
  3.86923189403572*^9, 3.869231903498217*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"92d33181-7fbe-4621-9f65-c928acf1fda5"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923c81d0fAPC7cO07pDxFe2pQaco5DW2VpkoR0V5o0B6KqIhU2kOlp6lo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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 3}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"I\\\\\\\\,\\\\\\\\rm{(deg.)}\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0., 3.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.86922753601637*^9, 3.869231474700179*^9, {3.869231897059352*^9, 
   3.869231905008359*^9}, 3.869231993316533*^9, 3.869232054609182*^9, 
   3.890977923505711*^9, 3.890977960428802*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"64e84c5f-4215-4889-b217-bf2f9baa7d76"]
}, Open  ]],

Cell["Plot the inclination of Uranus.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"45f69281-4d4f-41d0-a10d-ccee783af856"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pi7", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "iuran"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.05", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "iylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", "None"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diline7", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "3"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pi7", ",", "diline7"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8692275600606728`*^9, 3.869227576283963*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"b69f62e7-43be-454f-b0c4-8b86a95b3385"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3dczd8fx++s276jkhnZqyKZ6ZyEbCHK+PrKlkhG5Jvxy8zeu6+QTRkR
oXOsVIiUUWjc9p73tm+/+72f99E/Hj3Sp/s5r/fzfV7v93mfLgv9pi8R8Hi8
IiGP99+/3Jc5rV7W/9ULIz5W95p3+JVKQV3teKvzYltR6bQnnXaVKGjsgq1F
XW1bUPZm8wi3bAVdu6jwxOSRTej7lTUjDb8raMFGz9+zkhrQxw//fSlo0JVe
rhfr6tBr1X8PVFA3/vmfGViF/nvatCcKKlymt1E4uhppH6Z9ooLiuilymaQS
hf/3uCsKukqRnKgeWYbOnf3vS0GjHg9szWxTjLQfTvtABbXomL267/M89N/T
Ou1S0K882871s5Xon/8+3mYFvZ3wrObmJyXy/+9xaxS0hnSYNNMvDy3VfSlo
4F+f3o7zLUDzdA9U0E+TWk1GTS9C03UfUEGfb5R+6zC2DI3TvbCClpbf3NBn
TxXSPW6kgvLSUu5ctq1FDrovBf3n08xTAo0K9dY9UEGrZ/U7My2oDlnrPqCC
2sxtHa483oB0H89cQd87GB3iT2hGuscZKqhgxV63m9EaxOmhoBPipPOHduSB
HnIq29wBzznDw5weclr6pfp+Pxc+5vSQ095bHtxDwwSY00NOD/T7qLzQRYg5
PeR0smG9167TQszpIacxWya8enVbiDk95LRnzO9xfh+FmNNDTidav4xe5izC
nB5yOsejuSLomQhzesjp+SMNp4d+FWFOD+3zFK2dh2wWYU4POZ3QLujOUSMR
5vSQU6lyVviMfCHm9JDTuxsuCU2KhZjTQ/v5xifxFoYLMaeHnFaP7ikrUAow
p4ectmT2Gtq+ko85PeQ0vPNfhr1G8DGnh5z219yc45DAw5wecpo4r+BOuS0P
c3rI6a0d44IDnTSgh5yK7/W6Tw42gR5yOqX9Vbs+oxpADzm98CxzNrlVB3po
1zvke2NfiRpxesjo09Ol9R9P1gAfMjp5YMzJ0AOVwIeM1reN3Xu4ugT4kFGH
4FN+534XAh8y+sF3ZFLOhHykW75XMupcYX3U+qoS+JBR/d9B9k8aMoAP7d/r
+8+ENV5ZwIeM/n58EhVLcoEPGV0a0TNnRO8C4EP7vFrXubPOFgEfMpq6ml49
trIM+JDRaXtH9DI9VQV8yOiMhDVLfwbUAh8yGhc9ZJrVbjXwIaPTCw/hUa11
wIeM9qv1r4741AB8yGjS3znl8zybgQ8ZDWh3tnV2tgb4kNFrW2KuuExiesjo
TZVPn55veJjTQ0af6OuPeDWajzk9ZDT8WZ3AwkqAOT1k9HZIe/EHvhBzesjo
gx/bTYIPC4EPKU0Whe55fE0IfEhpyr/HvEVXhMCHlI68MzOzJk8IfEjp8fx5
q2Z5ioAPKb2YYWa5fJcIc3pIadnO/2096CgCPqS08MO+zVNvMT6k9Pryqq48
DyHwIaWdGoavGOciBD6k9PSiiWc+GQmBDyldV2PwQH++APiQ0nJrU1Q+lw98
SKnjIcfBRYE84ENK470Wm9751gp6SOmQ93FzFzzTgB5S+ldgo2Dv52bQQ0pD
jydaz+7SCHpI6cv4n66Fh+tADymNCn/1b/lLFeghpR2tHqvfj6iFfCWl0qyY
yRGyauBDSjd53NvkMLMc+JDSu77/qzbgFwEfUjrq5/lUf+N84ENKl82eNTRi
VS7wYEbHhYn7PemphPg3o0aTAn2fTM2CeDejzfkPna/2UkJ8m9H7Cy70XJuQ
D/FsRv/xOOBSklsM8WtGy/u49Dv4qQzplnuNGZ0equrgcLsS1sOM/lWWYu31
dw28vxldOfm9X9nfanhfM9p5qe/jPQ/rkU7OTmZ0scPX7xKnRngfMypqlgzd
Fd8EfJvSYZ8Om1lINMCzKX2c9HLV/Yk8rAuXD6a0IGulxEsbr1x8mNKaE2Nj
6+L4EA+m1MByYUtZTwE+onthU+r1yfduWJIA9DalT4s6RInvsvxnSpUzGp/r
TxdBvjOlU++GfcwJFGFn3Qc0pYV+eL/PfBHwY0pfr+1q7OAvAl5MaeSceXv/
ThQBH6Y0DA+wxBIx8GBC4ysVDUFJIoh/E/p408HdjwazeDehu0fMzw9+wOLb
hGbl5F4t3sLi2YQqj092Lp4qhPjV/v9ObRYlPRNgTg8TGmK+6empp3zI3yb0
wOlfZzve50G+NqGf/u2Ypa5rBT1MqFooO1T0WwN6mNCuae94nfq2gB4mNFO4
JHjaiUbQw5ju6r59MkqqAz2MaebvY7V9nqkQp4cxLeph31I8vBbypzEdstFv
zYHZ1ZAvjenT2ROLH3hWIE4PY6q0uXnoSm0R5ENjGvupteZtVT7wZkyXrt08
Kk8vH/gyppdz5oa7K3MRp4cxnX/TfWfOuRzgx5i6d+tx7ZJRHvBiTK1oT0Pe
6SLgw5jGdNxhaOlWDnwYUbedkQaRcZXAhxH1iv/5oGpiNfBhRL/sL43IuFgL
fBjRuwfSPQNP1wEfRrRiy9sno+wbgQ8jeq5yeYU8rwn4MKLl1zcOrhjZAnwY
0cZd7ccaWLcCH0ZUoe4b7ZHI9ksjalVjvTomi485PbS/X5VeeH0by79G9N1W
P8+HyQLIt4bUuX/wOIsJLL8a0k8o4Mx6qQj4MKQNOy46Wrxn+dOQGgS7zp5n
LgY+DOnc6mXPI9Qi4MOQ1mV3WjYjk/kFQ7qrr4/tQEsx8GFIwzV3Hz6YLwY+
DOni6k5L1G5i4MOQjiHdPC1iGB+GdOvTx4ZKOePDkEpPhIlFUWz/0P5/xee+
VTvYfmFAx7e8bn9YyvYHAzp867R1Q20EwIcB9bQxdeLz+MCHAX3m29R5RAce
8GFAzb+tDtYTtoIeBrTi2ASngJAW0MOAaiIudnzYuwn0MKDebdLNN7nWgx4G
dEJ0QcKsZJafDeitN0Yzr/WqBT4M6GjJ8XsRW6uBD+3nfbKiz3pZJfAhoe3f
2M0csqMY+JDQFQ2Lj62PzAc+JHSVOWneF5oHfEioRxyv8qxVHvAhoTmdijOx
YS7wIaGLms5JB0TnAh8S6mB+1iHhVSHwIaFHLj+b7p9eBnxIaItbWvnLr5XA
h4R2NqgP3Di2GviQUNtJi3oMc6oFPiT023BzH5k+81cSut2vZRD+3IB0y1ei
T2NevQ/c/JbVF/r0ispq+mBpC/ChT3scfdhj82kN8KFPM/tMKV25nOmh/flH
b8trh/iQr/Rpkt+jhDVTBbC/6tPIjNacKeECyFf6dGmf4c63agWQr/TptFXJ
kkknhMCHPrXqHO5zfIYI/Io+Fc7aERkbKwI+9GmRWY+1HSJFwIcevTXDeNLo
TSLgQ48uFwV7zQhmfkOPFnRYlfv7FeNDj17cPIakJzK/rUf/voI6Oc5k/lqP
+h/6IW13Tgh86NGB84+XBhmz/UOPensFnPKNZ35ZjybmGPSrXCUAf6xH36Cx
U+Mv8oEPPbouUOkdF8ADPvSo0YDMAOUHVn/o0bdeYq/Pc1tADzG9eMIltEjc
DHqIac9tscvKKxpADzE937zby1xeB3qIqZHPrGLZpFqkk+OsmJqXPd1iqs3H
nB5iam3TQz4goRL8p5h+3HRz4aOpZcCHmEbxXXmalwXAh5g+yLDatx3lAB9i
Knt11eViczb4FTE1/Lf774jpSuBDTOMC96yKHKIEPkT0xbJradNsc4APEe0S
F3CYN6kA/LiIHrWpTlpdWAp8iGiVV0aIx1NWj4ro8MclhXGTq8Ffi2ifgsG7
PsprgQ8R7ea5992w22rgQ0QnTre+47avAfgQ0YaTlUqXF03gx0Q0ZbNm8ss2
LcCHiNbMrn9dNU8DfIhodKFXUEZXHuQrEQ0Z0/R98Vg+5vQQ0sHnVk6c0JnV
e0JaLNwftXw7y1dCmuc3MODUAwHkKyFNuHTa84eNEHN6COk7s2kOOz6z/VxI
HQV6La+niIAPIX3vknJ7r7sI+BDSGTVrr14SiYAPIf3oG7bv7W/Gh5BaOCx/
5c1nfAhpaNaZ3LcWjA+hth5s6P07mvl1AY0PDfm7RMsbp4eAXo+MbRM2QgB8
COgiD/u0GynMXwm0PN60Vm9l/kpAx4xcPXTxRx7wIaAxkneBx2e2gh4Cul1F
Au5XNYMeAmpuXFscPqgJ9BDQXY8WDRqX1QB6COiTZRKbcwb1oIeApkWaDp4x
TQV6CGjZ+LD2s72rgQ8B9Y80dnxnVwl88On5+3/7ShaWAR98utZ17Ng5yUXA
B5+Wmlemr8/JBT749HvWjosjnmUBH3xqbZE7cv6cLOCDTz2Tjty5M4b1L/hU
7b1j1L9Pc4APPiWhV17W7coDPvgUTQwrHRlfBHzwabsfBr1mPK0APvj0id6x
rQ/Xs/2DTy3NF53sp/X/nB48eikg7vzoXyrgg0erunXfWGxfD3zwaHCMi/qb
QRPwwaPx5qG9Cte1AB88il3G7x1QrQE+eHTwhW1Hy0Q8yFc8anPDx0ul1YvT
g0c7tuvjLsvgQ77i0Zj2AW67E1m+4tFh0TOmrHAWQr7i0UV9fC2O/i2EfMWj
iaFJrsvD2H7Oo+WPk8cesRXhb7r1byWdnJe/P/ZIBPHfSt45TRt04aMI79St
bytZt1E49eVmFt+tZE3Xxwf1eonwQN36tZJnDc8zHLuy+G0lX4eZqP20fjlL
tz4asmHcO01DBeufaMhcZcisswOE4Gc0xDDu9jjvmQJ4Xw3JCr220PclH/yK
hrgF1a42X8TqXQ35ENr04nw86++0kOC1aw9U+bRC/LQQ0wWDRl1Nbwb/10J6
uY7rWvC+EfxFC3G4G35pxHxWj7eQw83Nz1yf1oF/aCGh43es/zBYBXo3E2//
+2VbRlaDP2gmsx6PnTdXGy+cns3kuWJDqn1aKdK97uZmcninw6IRsmLgp5m8
tHmVxTPLR7rH9WomnvrrhqmClcBHM+k/MfH3plAl4vRoIvwv+NpE3zyI/yay
7MX4Qc+TCxCnRxOZ++27rR8pgvhuIrLtLtdd55YhTo8m0u55xpTnu6ogfpuI
d+axk6tm1yJOj0bSIAntu2GeGuKzkexvXpZFs+rAzzQSsvW5QccfDZAPGknF
drOr13Y3g19pJPVd+g1c3aUVeG8kKm/Hz1V+TI8GUnQTmy5T8SC/NpAa0wWD
1x/jg99oIHMXCy+n7WD1UAMRdTs+oXKrEPJlAznOH53x0FwE/rqBSIuXjp8/
nPmFemKbtsI30YP553qynyrXeTxjfqCejJBGXgkaLcacHvUk8Y4bvzCI+eF6
sm2rxYDPQ8WY06OeGKFUnlE8qwfrye3PU6bvO8n4qCOhvgtiFocyPurIgHZt
gp3XMj7qSG6d6aC3iawfV0cC/dtXtPkpAD7qyO1srHzThtUHdWT5xhkWsy7z
gQ81GV52pzK0A8vfanJ0WXjGlR484ENN4uI3dx8f0QJ6qMm4rTUXf7o1gR5q
8sXSxHX6RdYvVZOS6EsHr3aoh/pJRV4cH33pRpYK+FARdY9J53wrqoEPFbm1
PtMVuVYCHypyMrQm9i/M+rna74/I+szMKwY+VIRfc7md45EC4KOWfEodnBZQ
mQN81BKnfkuGjB+ZA3zUkpCMFZ92NOYBH7VEQ3fLzOoKgY9agidMWm7HKwE+
akl6SW8k/FEGfNSS4VZ0R8O6KuCjhkybePRk2iJW79WQgrHdIldHqoGPGvJ2
LKo5Nbwe+KghUXG3QwJ+NwAfNcQ9ZEXcfcz6yTWkPGzytJXlGuCjmnzacilA
8g8P9KgmV7tdn0uM+aBHNRlYvLb+6h4+5KtqsvFEblnsFAHkq2riNli5eMk4
ln+ryeFNK1128ETARxUxilw/uqcT6ydUkYnzb8SccGb94ipy5cN81fCNIuCj
ijRs1zuRVsX8RBVpt6N29/6xYuCjikxobd/OvrMY+KgkhVsGrve+wvioJEnq
I7FloxgflcREHNnzjp0I+Kgk609dSk9qw/opleTJ+csxFseFwEclQcvP9vLQ
+n9Oj0qy5Ji7m0c0H9/TrX8Fuek026JVG79euvWuIFPbxm85HsbDEt36VpDy
7HMD+15shXxTTkLKIurq2rag5br1KydBN5x+zF/ViKS69SonDpLIeQNW1SOq
W58yYu+X8LRdiRris4wo9KOvzq6vRZ11719Gesx3LDLrX40+6963lCSn9Ryx
LqAcbdK9Xym5Qmcufbi0GOKrlHyznOvjLi9EP3TxVEK+P3p/pNtfeWgvZ1DI
xSH9+pGSbGSvi5cSkhAWQMu0/oOLj2JCE41Wtj+XA/mymEQHj28c51eAOMCL
ib/dvyXxXYtRoe5xReRjxfW9vzJL0RmdvkXk2+GHiyNeVQJfRaSL6qT+rdga
VK/7gIXkzoGHVQJ3NQrTvXAhGfzye0SOsB656xawkGwa0/RhwKYG4KOQ5CRX
j122rwlxehSQG/yVal4PDeL0KCBxgtEnwu2ZHgUknT+yaPo3Ft/5xKbLHSdr
Jz7m9Mgns1FDXGAqH3N65JOaoSfXOkULMKdHHllt2atTznYhxGceadqcfnNM
qhBzeuQRvxibiGvafBiv0yOXDIzu0iVZ+3NOj1wSf/nIBY/+IoivXHL5vcwu
eJ8Ic3rkkOmTepw7u02EOT1yyMRuaXs9hCLM6ZFDPv9NlZrNQsifSpIbv1Ma
7cz8hJJ4HPxwtUsPIeb0UJLFMzZVRcUKMKdHNnF5urbPkd98zOmRTRIGPE+7
kML6b9nE2mraoigTHub0yCIS9CYi06wV9MgigauuHc251gJ6ZJF0khWhN70J
9MgiB7q9HD19Rz1aoFv/TOItPLTR0VaN7unWO4MUHf7UxuZwLcR7BlHLsq7E
plZDfP8m25dLbzuMr4R4/kVOBow2vXq6GHXWrdcvMvBnl95Cq3y0Xbc+P4lF
+pyfuaJciM90EuuX2uDmrYR4TCdPJx3zPtYzCx3RvW8aOexx5fehhkxUqXu/
H6T7fTGN/ZwD7/ODTHwfFjg7uhDi6TtZ91nddpRHKZJyhp2EWJGq7VMr0AJd
vHwjc2+XLxalVgGvX8lUx+zxb98xPr8SR3Pbz6sP16HtOv1TydftsjAXbfx+
1j0uhZh1UUjef28E3lLIj3HDbVaebQa+vpAYnNbnhrgVVer0SyYnfYydV0Tw
MFcQab8vLaxW+/Axp89nEvz1pf3Pd3zIV5/JugHHj5gM0savbv2TiLPljw6Z
VQK8QLfeH8n1Z21/RLzQxq9ufT+Qj3S2wLcn86+JRLh3aplNRxEO061fAjkv
Cnsc2KqNL916xZP0HwtPd+ur9Q+69XlHAvd/qVimjV9uPd4ScXpxxq0QEebe
/w0x+vpzc5alCHfWve9rsn9zbtWNNdp41r3fSzK5+UO5p1gI70PJ7gkef81J
Z58/lgxbFWQyYpcAc4bjOek2rd/Lu4/5eLvu8z0lMTdq+7w6z4PPE02a5zRa
+3m0wvpHkcvu6T5jrDSIp0v490ngYWWKMKkZbdc9P4LMm71gvf/dRsQ97yb5
vNW4e3Ia0y+cOB08s+DBKBXi6Qqmf0nqzuaY80E1iKf7+QlycH/HwRvLq+D7
neQ6v9anYUkFYifoM+KGze/6uoj9HH1M8Bz3XJt/eRa630eLf/fZYqn1E/B8
9Lfq+q02d3LY30eBBSebJ2Ur2edD3pkNyYF/sf8fgTz3NHfuhQrY+yHZ212O
xpdK2fujgb2kGf03VCJYH/S0QHgsslUbv9z6oSE/B8UmZdYgWF/kc8tlpv4F
NYL1RwPOzDgZuLsB8gFF20f5PO4R1YRAP/R1Wvsai3YtiCv4X6PgfPs3Dw9q
4O+/QXWjN+yP8+Kx+EBtPvXq3rSPz+IHpRaE9Ddfro1PLr7QqZM1WWGfBCz+
0Ls9p+f5tWP5LxG1udm4/v6dP/GLSGyP4b/9tfHGxTdaNy+iMr5OxOIffei1
9nNzK/O7n9GCTUumfEkQMX7QpCdRJaq3IuzO8YVsw6PtTfTEGPhDW1KGb7Tq
LoZ8+wXJXq+zJIksP6egDV1veFho/UQWxzd6GNnpqPkWIcR/KvrfhEHB3wey
/eIrGj23tCK9iO0vX5Fq4elzb4do6wMuv6CD8nKz/Pba/YjLP6hnReeflgIe
+I/vqKZuoGb5Vg3LX+h2Sbt5+aiF5TdU7ntsc8rfTYhbvzTkMGzAvqDwepYf
0bqEheXzUlQsf6IEuzzx8MQall+R84sgM5ep1ciey79oxdw9Tw4t+5Of0dmJ
dPn1YyUsf6OITyc6HMzPZ/kd0ePpopHD8iB+MpD1pOnKV7vz2P6AEnYubJ29
Ko/tH2jAN/WyqHN5bH9Bn5KX9PU5VohucPsP6ur/1MHmexn4hSzUZ+jwd+1n
VYGfyEYZhRbrQjXV4DeyUYcdeoIfJ2ohf2ajbVMFGadq1fD+SmS2v4/yUUYD
5FslsnALXB8wsxnWQ4kMun/ucySvBQ3l9l90vem43LtrK/ilHPSvs9OVnQE8
tn+jWW/CLqsu8tn+jq5sy157L1TA9n9UfiHTJaWLEHPrl4sW7NRLuz/vj39A
yjPho21f/vEX6Nf2V/F1a1g+zUPDHxg05JuKsRXnT1DC90EvT2nrOfAvKNux
TGmtYf3ifLQ55BVemyRi/gdJbyUn1JaKMLf+BajWqpupj5UY4qkApUeNW/R3
NuOjEAXxhAlBjloeOP+FnpyNGV++QYg5PQpR7+h239bzheAXClHna5oLOU9Y
f7wIbdyx5P3e3gLwG0XoWfMTS70ufOCpCPlXPSgv+NbK/COa1W6B/6DaFuYv
UanU+8D7S0yPYmRh4ZHyUdAEepSgH73jnLZsq2f+FXUrX1x5aI+K+Vvk0v6q
fXy7GuZ/0XxByeuHW6qYP0bnFV+c296oYP4ZFfG2mXRIL2b+GtlOimq9+SSP
+W+0rWfKd2X/HObPUdqIN9PenclBnB7lyFC0qcbJKZf5e6TetLTflJO5zP+j
XpIC94PCAgT1AUr2kETT7qXAQwVaKlabjdf6Y6gvUERRbubAu6yfWInCukve
P+pfC+9Tic7suzVr+gg18uDqF7TtV3DVanEDCuLqG3T/e0uSQUQT1KPa74tL
XppvbIF6tRLNOvN4WMNFDfBUiVI3npGtkvAgHquQ5Pa4LwUWbJ6mCnmlHnB4
Y8P6F1Wov+y15z9vBPgCV7+hflVb/XGLAL/h6jvUo/UROj+EnZ9VIYtTFWk2
L//Uh+haLa3rtEgEfrUaraVN4yxviyCeq9GdjW5L4gPZ+V81aq2Wp77ryeK7
GhmtyKv70pb5lWr0oPHUTZ62njTm6lt0aoKf8EtXER7E1b9o/6O8CO8DrF9R
g/KHNg8Z81gA/YwadLsctY9UCICHGuRYN7HHwKd84LsGpcgEQUdHMX9Vi/qY
L/Me48kD3muR3cwVed/tNKBHLVq8pOj54tom0KMWndq/Y+ck30bWH0DJ58sP
bampZ/0DVHzwbYerUWrQoxZFLVl65J8XNRCPKqR35qi3iYbVTyo0+2BO87Up
5ax/gVwKvxYUzShBnB4q1LVR/9G8/gWI00OFioa1d1nmrGT9EeTpoTwxfUEm
658gnwGjvqr42cCjGn3IHjhO0T4H4lmNtv/j2sXrNDv/U6PQlOgffRYWQHyr
Uf6BXutDrpcCr2r0wtg9+LxrFeL0qEOkZFene1q/xOlRh4a+OeTcxkQF/Yo6
FL79QKV9Butn1KGu4aZ/BaxvAB60v//Y03/0gGbguw7ZLRfR3nbsPKoeWXXr
ay+c0wp81KMXZ+237EQ8zOlRjwrn9PLN68bHnB71qFcP7/btbQWsf4Z8FZ3q
V+YLWH8NndxT+SyiO8tv9ejnZ/v5S51Zvm5AKVHWryrO/OnfobOv1Z7ufVn/
QvvzAxWGbrtFwEcD+nikuvWRNt45PRqQ2j//9fJGxkcD+kfT8jriOeOjEU24
55zb+x2r5xrRt8+d0yNihMBHIxo2h9+7cSir/xpRFEkm07wEwEcjqlAesh+0
j/XbGlFb04Vfn5jygY8m1D30ZDevizzgownZaq66el1oZf1V9PbxXyXTbFpY
/xX1v6q+HHipEfRoQia2x3/+k1oPejSh2K2J2wIXs/PaZpRiEPHt1CIV6/+i
/qdPhMgOVgMfzeiyai0/e2YF8NGMOo9r0itdWcL6y8hyjaXzkZJC1n9G6Wfq
ar9r90FOj2Y0/kDNj7Bv2cCHdp8W+P44My6L9bfRr7Kyo6eSlaz/jZpsRuf3
R/nARwsquHC4RXSrEPhoQSOLVmPDzSXARwvyrnA4s2lQJfChQRc8lnoRpxrg
Q4Mm3Ut/6UZUwIcG+bpOCdm9mvWTNWhnXuU/w7T5GPr/aN5m0/55k5uADw36
Wfa8V6i+BvhoRbXBZS8Od2Z6tKIRS/2TN8bx2PkDOn019egiZz47n0AO/WO7
zlWzflQrOnvW/+6+SgHkq1Y0JfUZfk/+nH/gSTm3uyw3Z/MO2r/TTTWstJ0I
9+HOT7D6QmyceCybJ+LhG/4pPYOfs/4YD78Jx+OGdGfzFjy8Y03M+XPtxcCT
1tcfuvv91y2Wr3n4cePRvncx67/xcE8//1Hu3Vn+5mHrYY8uTuogwknc+RH2
5PX/x+CRECu58yWcNiJKc+4Hmyfh4dGS2gzbfD70k/l47dE8OhbzgUc+Xn2j
paToPVs/Pg6eMSjktQXrb/Cx9fohZUHJbN6Fj88G9NZf24XNw/Dxtgto7W2t
Xru58zXc+bfv7y172TwNH+9po3qU+FbFzufwkF/bvw7oXcPO7/DU9zyLPsMr
gQft8ybYZSfblUI8af+eauJQaQWb9xHgtP+1cU66VcDOD3HQbLM4+bZcxOkh
wG6zZt7L+KqEfrd2Xz3f+1ikVR47n8RlMe6rP7WyeQsBvpM3E58vKwGeBNjx
XdtZghXlEI8CXGAb0LTcpQr4EuD1Y19m9enP5qEE2PP3btcLlWrE6aHd52/8
XL8rrR5xeghwbo9LX1ZMYvNWAtwxaXj7y0NYP1mIZ3+aueFUkgZ4FOKn3jui
V4cxPYR4zHiHs2+WMT8hxBZ5Htc6/WDzYEKcW7Ko6eki5i+E2PakXedwFyHm
9BDi3t26FxXbsH6xEEf039M77Rw7nxDiis/GH1aEs/6yEK9dlpPV5jrrrwnx
3ve8iavVrB8txG9c5/PjF4nZ+Tm2f+EeZRckBj5E2DVz6b4ObcXAhwjra6KC
/A8xPkS4pOuegV3HMD5EeHxQ6K1LDiLgQ4QPvB07paFYCHyIsNEpb9eFPVi+
FuFHEpOtk6zZ/iPCnwuu1Q2bwM5DRHjn5fdv3r3iAR8ifMtr/pYPPXjAhwjf
+yUOSHPQsPkFvNRp1qXL65rYfAMOmjdU9bGlHvQQ42H3xvvcnFgH+68Yl3y6
NjbmkYrNT+BplhO2z11Yw+Yr8LTDiWviV7HzETG+f9UgfkJKCfAhxlLH/Wsq
OxUBH2J80jLeHI8rYPMduPjdCUHS8Vw2/4E/L9gz6uZSJfAhxqfPyQZ9+50D
fIixbfj5jB31BWy+BE8Ytvj695AS4EMPb2l9vHSwZTnwoYdL5XNTRrxh80R6
+HROgXfGphrgQw8nrJzZcctiNm+hh0815CX6nKgHPvRwyB47j3SDRuBDD19Z
6b447Qrzy3p4Uuf/OaTUtQAfenjPxfxF7TDTQw8fPV+Se7A3H/TQw8KX+j1N
L7P7EXq4/YP1ghUG7PxLH0c0XU+//kIA+UofP7WuG3kzVAh86GPbOMumcY7s
vEMf7xPsm+XyZ75CH78t3JOxfIgIr+Xmk3Bvq810pJcI+NDHn8oD4vZFMz70
cdmeGW+Lixkf+jg71jSw/2XGhz42GP492EXC+NDHC31uDt14hPkRfey54/nU
dUvY/iHBnw/MS4u0Z/5EgvM1lcmigwLwvxJsU+Jj1H0nHztx8114Uf3fe2/u
ZP5LgnfMcl/7LaoV9ksJXtKa2+R1XAN6SPCuKqXv7Zes/ynBTk9L91lZML8s
wX5pmZvdZtax+TQ8nSY4tndn850S3KnC5MD+VzWwv0pwWdHrlz+fVIFfkOCd
4T0js9+WwX5rgE9MyEx+Z1cIfBjgHze6N16rzgU+DPDK6sHtyg/nsPk7PPnw
l684OZvN5+F7Wasjh6IsNr+H27atEM0xUIJfMsBjrfXfRn/Jh36EAQ45Unoj
zr0E/JMB9irKeWy/uhz8hwEWlm/ND/7J9g8D/DhiWMksb3Z/wACv6YFu2c5T
Ax+GuONY1aZ3CfXAhyHe+7++LxbMbgS/ZYi/xBzsnhnThDg9DDH+Z3m+x4sW
8F+G2GnopUOD2vHATxrirelHhlxtx/yxoTY+HUaEXmLnf4Y494gBvlTB5msM
8bAMw86N65nfNMQf/e5OvYOEbL4T98ta4tOpkPXrDPHLbUtNxrURgZ82xO1S
rMZbVAjBjxrh74rYa/uymb82wrMU/Ny+XVj9ZoQD2s4wifyL8WGEDx1+anGt
P+PDCAummPP2HmH9EyNsbzO7JaqC1Xfa5y/+8mR+KOtHGOHKKTUhB5azes8I
b599IcI4kw/+3Ajvv3vjd2gG6+8Y4TbPv/s5bmX3nYywZv/OK8tSW9j8Lh7z
fGapXOtbYb4XLxxNba6Km0APY7zKacGCLtvqQQ9jbKktYceeUYEexjhsw6du
rW41wIcxtlv8dUJtZBXwYYxPTPnQTpT6Zz4Zz179OMU1qpjNL+P/dZpgkInY
/KYx7q9INLMepWTzz9jA4MiukfpK4MMYv6G/uynrs4EPYzzSe/8mvZxs4MME
31J+3dNmaS7wYYJLd2U/3He3CPgwwXOur+p7pKQc+DDB3XpeNH4zuQr4MMG+
eY7pfkp2vmOC6yxP/7rUTQV8mOCQtUfmmEvrwY+b4Njj66fwH7L6wgTLC05c
VPk1Ax8mOOvCocPjI1uADxMsKFknujSb6WGCd2UXF7l+YfNwpnhJWYZ1fQ6b
nzHFioTFX64Es3xliq+HC/+NeyuAfGWKpxZ0nN5G61s4PUyx84yVTYlxrN4y
xRnduiyp2yACPkxx6pnUhJoXzO+aYmTROGDHCeZ3TfEU4fUDS+Yzv2uKG6+O
fLJsHTufNsWqKWvcu99m/QtTvOHTs/CPxxgfppg4qh9t0zA+zPDpMDsbiz/1
pxmOiBq2eL92P+H0MMMa+wa31EDWfzPDG04/5XmK2fyqGR52421YhzZ84MMM
u88J++GZ0Ap6mOH36eFvxiS0gB5mOLZ13iXjNc2ghxn26/7Fza+xEfQww6v9
Q5yyb7H6zwwblrz5uuuFit3vwElbvwRdtqth9z+w4kV0567BbD5HivEL6Rf3
pgp2fwQ/Wo9cZp0qgXkLKU7yHvKrYWc+7PdSfKBy/r6yOzkQf1K8WzP94ZsO
bN5eiqeWhDdvs2XzblJMzdd/zolmflmKK8RdLA/Fsft8Uhw0cPjUokul7P4M
DndKGzSocxXEqxT3u7OijzOuAf6k+MPFnUPKE2vB/0jxwyCh+sQDNfCo/fxj
D7z2WN4AfkiKa3vRY7LBzcCnFPPumdutHcHmkaXYzfG60ngLmw+Q4rF8u8Kt
Pmx+SIqn9x8YPnIVH/yGFM+yGD1sVwir76Q4xf1Ye9+JrF6S4pCGcxvXnflz
vwmbN/4qavfxz/0nXJj7hS6ewPq7Mpz8oqBOo2LzazJ8ZpOte/u/mP+V4Rn9
/aaN+DNvIcM9znQKC1GxelGGp6bWe55LZ/lZhq9sMBFO4rN5exk+4LB7s1Ag
hniU4W8Oehcm7WV+WYYT53U5Wv+U9eNkeMGBtGl1hmxeWYbP12/wbbjN6gEZ
Fr6N+d/b8QLgT4YX6u+ngUF88D8yXOyQekU8gc0PyfBMyWSLnq4adv8Nayav
M3t2jekhwzc7tx73H9/E7s/hBItsx72urF6X4UP/es0Z76tm9+/wjMndN6jP
1EB9JMMfAhzO7rlcBfEvw0Nfl/U74lgJ9ZIMv1vrNmTodVb/yXC3Nz/KOjxl
80MyXDd3m3x6p1x2fxCnL3O2SpblsvuFeI3NwilTLrD7InJ8NK9Ur9uefOBD
jp3yd1zezysEPuRaP7Lo7imrUuBDjq0en0i5nc/8sRy7nDnnvGoGu/8kxyn9
u47r0lALfMjxi9AxD7PPsvt8cux69IdLvqYe+JDjxFku49+nsnpZjtvte/Ex
1Yb5Nzkebtg9Yc3eVuBDji8e3GxsMIPpIcenR1rZOvdm83ByHBFotjd6JKt/
5HinKMDua6c/90uxm5m32+mdf+6f4p8+u7rOvyoEPuS44OtxiU+NEPiQY+ud
9gdFf+Yp5Dj7XN/z1yRi4EOOJZMePIuSsvtOcrxx6LLtgU/YfJ329xuGDAxY
w/hQYLeekVZ1AYwPBT63Mar14S7WP1HgCvst1Xw7Nq+nwJqhqf97uFQIfCjw
3gXo0PyjLD8r8KDJnQd1N2TzUgp82v3CMp/brB5W4LZI8cNIwOZdFXhZQYL/
8tesH6fAr/u+7317CJuHU+DfE9EKJ8z0UODh+SG7/b6y/r8C25wY7H9ZUQ96
KHDYG2fPHD8V5CsFltfWdfnmy+bhFHis08HfU2R/7ldjy+3D3Pu2L2P3rzES
RV+xyyli97PxzFJZh9WeecCHAn/fc2F028nZwIcCL+kwz+dkYxbwocBH6MX1
dpNzgA8F3tbHrvarYx67P479B/h06NGSD3wo8N2J3Q48TS0GPszxRZt66z1T
K9H/AWdaXnY=
       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 3}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"I\\\\\\\\,\\\\\\\\rm{(deg.)}\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0.05, 3.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.869227594159616*^9, 3.8692314747881927`*^9, 
  3.8692319173232813`*^9, 3.869231993405386*^9, 3.8692320546609507`*^9, 
  3.890977923572504*^9, 3.890977960489644*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"ef82f232-8287-4b0d-913c-8d1559deffa3"]
}, Open  ]],

Cell["Plot the inclination of Neptune.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"540092ee-8d88-447d-acc5-14674b6564b8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pi8", " ", "=", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"time", ",", "inept"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.5", ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "iylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.5", ",", "1", ",", "1.5", ",", "2", ",", "2.5"}], "}"}],
           ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", 
            RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diline8", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "2.5"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pi8", ",", "diline8"}], "]"}]}], "Input",
 CellChangeTimes->{{3.86922761952168*^9, 3.869227722720471*^9}, {
  3.8692319390070963`*^9, 3.869231946714138*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"dbde7bd1-8bbb-410f-a460-3a5884347e84"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw923lczM8fB/Dd7a6t9nCfyRG5cn59kRlyRXKWRF8RSUhu5aYQcl9FjiS3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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 2.5}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"I\\\\\\\\,\\\\\\\\rm{(deg.)}\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0.5, 
       FormBox["0.5`", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {1.5, 
       FormBox["1.5`", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {2.5, 
       FormBox["2.5`", TraditionalForm]}}, None}, {{{-4, 
       FormBox[
        RowBox[{"-", "4"}], TraditionalForm]}, {-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-5., 5.}, {0.5, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.869227684099093*^9, 3.8692277231612186`*^9}, 
   3.8692314748772717`*^9, 3.8692319499182043`*^9, 3.869231993491055*^9, 
   3.869232054710813*^9, 3.89097792363336*^9, 3.890977960548409*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"2649d287-48d8-418a-b976-42f00b6433e7"]
}, Open  ]],

Cell["\<\
Now we can consider the Jupiter-Saturn system under the Brouwer & van Woerkom \
solution.

Set up a list of the times we are interested in.  Here we choose the same \
interval as we used in Fig.7.1.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e2ef93c3-3c7e-46c6-bc6f-9ecf6b31a0a6"],

Cell["jstime = Table[ttt,{ttt,-0.1,0.1,0.001}];", "Input",
 CellLabel->"In[58]:=",ExpressionUUID->"5788c09e-2161-4143-80b7-726c1a84a1ad"],

Cell["Calculate the eccentricities ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6abfd1e5-fd95-4e55-b290-6768286bdbcc"],

Cell["ecjsdat = Table[Brouwer[tt][[3]],{tt,-100000,100000,1000}];", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[59]:=",ExpressionUUID->"acedb428-07c2-45e1-b31b-cceb4e88748c"],

Cell["... and inclinations at these times.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"eeb62851-74b2-4357-8e88-05aba2cd0cea"],

Cell["ijsdat = Table[Brouwer[tt][[7]],{tt,-100000,100000,1000}];", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[60]:=",ExpressionUUID->"b50a7778-a455-487c-8cd6-fa672d34f214"],

Cell["Isolate Jupiter's eccentricity.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"daa75b68-844a-42c2-82e1-10e255e747e5"],

Cell["ejupi = Transpose[ecjsdat][[5]];", "Input",
 CellChangeTimes->{{3.869230647109683*^9, 3.8692306564682083`*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"8c8335f8-a4c8-4228-b104-105d58d20e9d"],

Cell["Isolate Saturn's eccentricity.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"002ee8b8-611e-429e-ba91-b8502d8c9a81"],

Cell["esatu = Transpose[ecjsdat][[6]];", "Input",
 CellLabel->"In[62]:=",ExpressionUUID->"e41316ec-09bf-4f61-b9b2-9acf28935601"],

Cell["Isolate Jupiter's inclination.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fdfa9363-0aa9-4b56-9c0a-cfe93a60d640"],

Cell["ijupi = Transpose[ijsdat][[5]];", "Input",
 CellLabel->"In[63]:=",ExpressionUUID->"8ce562a2-f580-4511-855d-3482bd632042"],

Cell["Isolate Saturn's inclination.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8ab7754e-c380-4313-b28e-17ec4bb01811"],

Cell["isatu = Transpose[ijsdat][[6]];", "Input",
 CellLabel->"In[64]:=",ExpressionUUID->"40dd5dd5-8f48-4b66-a8c0-cfceca6332de"],

Cell[TextData[{
 "Show the plot for Jupiter's (",
 StyleBox["blue",
  FontColor->RGBColor[0, 0, 1]],
 ") and Saturn\[CloseCurlyQuote]s (",
 StyleBox["orange",
  FontColor->RGBColor[1, 0.5, 0]],
 ") eccentricity.  This is the left-hand plot in Fig.7.11."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869230752004468*^9, 3.8692307688942537`*^9}, {
  3.869231176295967*^9, 3.8692311860454063`*^9}, {3.869231385952318*^9, 
  3.869231398626382*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b0f96742-cc9c-41d8-8f4c-7284b98f5238"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pejs", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"jstime", ",", "ejupi"}], "}"}], "]"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"jstime", ",", "esatu"}], "}"}], "]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.09"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "eylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0.04", ",", "0.08"}], "}"}], ",", "None"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1"}], ",", "0", ",", "0.1"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"delinejs", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.09"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pejs", ",", "delinejs"}], "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.869231011608721*^9, 3.869231011621171*^9}, 
   3.869231068358189*^9, {3.869231104088686*^9, 3.869231126871202*^9}, {
   3.869231609830234*^9, 3.869231638447875*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"94c5c14f-977a-43e1-85e3-79e4e6b79fdb"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9VwtUTfkXbogJYUQ0MQzRkEcakxT5ZFL4MypmVhGjaCTpJdU03s/ynkJJ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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1lws0lPkbx5G1VEsXxya2LStLGxXVP8V+bZcTrW3R6m+jK22tjVV/Rbbc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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 0.09}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"e\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {0.04, 
       FormBox["0.04`", TraditionalForm]}, {0.08, 
       FormBox["0.08`", TraditionalForm]}}, None}, {{{-0.1, 
       FormBox[
        RowBox[{"-", "0.1`"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {0.1, 
       FormBox["0.1`", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.1, 0.1}, {0., 0.09}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.869231069517106*^9, {3.8692311309171257`*^9, 3.869231152967846*^9}, 
   3.869231475114139*^9, 3.869231639967656*^9, 3.869231993707279*^9, 
   3.8692320554353*^9, 3.890977923793458*^9, 3.890977960709453*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"784f8435-32e1-45ec-b51f-d9d523f5d22d"]
}, Open  ]],

Cell[TextData[{
 "Show the plot for Jupiter's (",
 StyleBox["blue",
  FontColor->RGBColor[0, 0, 1]],
 ") and Saturn\[CloseCurlyQuote]s (",
 StyleBox["orange",
  FontColor->RGBColor[1, 0.5, 0]],
 ") inclination.  This is the right-hand plot in Fig.7.11."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869230752004468*^9, 3.8692307688942537`*^9}, {
  3.869231176295967*^9, 3.8692311860454063`*^9}, {3.86923132673166*^9, 
  3.869231329040595*^9}, {3.869231407056797*^9, 3.869231410715804*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"569f5085-8dd3-47ab-bf73-afd57b66de57"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pijs", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"jstime", ",", "ijupi"}], "}"}], "]"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"jstime", ",", "isatu"}], "}"}], "]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"Joined", "->", "True"}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "iylabel"}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", "None"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1"}], ",", "0", ",", "0.1"}], "}"}], ",", 
          "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dilinejs", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "03"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pijs", ",", "dilinejs"}], "]"}]}], "Input",
 CellChangeTimes->{{3.869231253202423*^9, 3.8692312945114393`*^9}, {
  3.8692313554748373`*^9, 3.869231355982182*^9}, {3.869231504229842*^9, 
  3.8692315263844957`*^9}, {3.869231654109717*^9, 3.869231676532612*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"b3daec87-d277-41c6-b4e1-c9adb8398cde"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9VwdUFGcXJUgMBGMlYiExRER+EiQEFVHkLglYiFIsgMSjBjRR5BdUJESw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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1lwlYjfkXx++97y3ZEkYqu6asKRGpxvn5hwZjiCgkTaKGjCbhSlSUMNEq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       "]]}}, {{}, {}}}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0}, {0, 3}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"I\\\\\\\\,\\\\\\\\rm{(deg.)}\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (My)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}}, None}, {{{-0.1, 
       FormBox[
        RowBox[{"-", "0.1`"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {0.1, 
       FormBox["0.1`", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.1, 0.1}, {0., 3.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8692313003931026`*^9, 3.869231356549087*^9, 
  3.86923147518353*^9, 3.869231528186575*^9, 3.869231677066102*^9, 
  3.8692319937827473`*^9, 3.869232055532493*^9, 3.890977923847299*^9, 
  3.8909779612432137`*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"0ea78c58-d4b9-44b2-a77d-78604f9a2153"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1030, 661},
WindowMargins->{{82, Automatic}, {Automatic, 25}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"26d9a8e0-6505-4489-bc90-b12c302856c3"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"2f3ecb44-8c1c-41fe-b989-801d605010f9"],
Cell[1000, 31, 96, 0, 67, "Section",ExpressionUUID->"7fef9d84-149e-45a0-8a86-b4329eb70594"],
Cell[1099, 33, 815, 30, 95, "Text",ExpressionUUID->"4fb76925-797b-44f6-84c0-87a325965505"],
Cell[1917, 65, 12676, 291, 1312, "Input",ExpressionUUID->"4952c245-cd75-44d2-8752-1611fb8ac6aa"],
Cell[14596, 358, 281, 8, 53, "Text",ExpressionUUID->"1c9bd0f6-1df9-4a93-a327-d87924ce016d"],
Cell[14880, 368, 390, 10, 30, "Input",ExpressionUUID->"45136d95-4b7b-4853-99eb-4074ac28b597"],
Cell[15273, 380, 219, 7, 53, "Text",ExpressionUUID->"de3ed58c-f7e5-48cd-a283-896452855a5f"],
Cell[15495, 389, 500, 13, 30, "Input",ExpressionUUID->"78e086f6-3f1c-4d30-8c87-faca00eedacf"],
Cell[15998, 404, 217, 7, 53, "Text",ExpressionUUID->"40569932-731f-420c-a31c-bd55aa932ef4"],
Cell[16218, 413, 499, 13, 30, "Input",ExpressionUUID->"9e24b7d0-0f99-43cc-b928-458f3c42f82c"],
Cell[16720, 428, 168, 3, 53, "Text",ExpressionUUID->"d433d43d-4f35-4582-bac3-f98b002bc479"],
Cell[16891, 433, 413, 9, 30, "Input",ExpressionUUID->"065ec682-f012-44cb-ad4e-73d35f5a95b3"],
Cell[17307, 444, 166, 3, 53, "Text",ExpressionUUID->"c728e08a-5abd-4ee1-bc19-a43ab3a03ea0"],
Cell[17476, 449, 403, 9, 30, "Input",ExpressionUUID->"df3a360f-5ef5-454a-bb17-365452cb1290"],
Cell[17882, 460, 883, 18, 75, "Input",ExpressionUUID->"6f296be4-33f0-4a68-939b-c0bcaf038739"],
Cell[18768, 480, 159, 3, 53, "Text",ExpressionUUID->"e63e2045-f9b4-43c9-b2db-38630e3aa82f"],
Cell[CellGroupData[{
Cell[18952, 487, 2400, 66, 157, "Input",ExpressionUUID->"4dcabdab-5b72-4e0f-9f98-7764cf40fc1d"],
Cell[21355, 555, 19046, 352, 256, "Output",ExpressionUUID->"261e1e54-45f4-4f3f-8572-ac80f66205ee"]
}, Open  ]],
Cell[40416, 910, 157, 3, 53, "Text",ExpressionUUID->"dcebdda7-a6e6-4f7b-9ffe-c694c3a1292e"],
Cell[CellGroupData[{
Cell[40598, 917, 2344, 65, 157, "Input",ExpressionUUID->"678d4471-13cf-4fa6-8bf2-c51a800c6aa1"],
Cell[42945, 984, 19219, 354, 256, "Output",ExpressionUUID->"eed709a0-c7a6-4e95-bf69-2e51c39efe0b"]
}, Open  ]],
Cell[62179, 1341, 157, 3, 53, "Text",ExpressionUUID->"0094e0df-a937-4a45-85b3-4a7b777638ee"],
Cell[CellGroupData[{
Cell[62361, 1348, 2346, 65, 157, "Input",ExpressionUUID->"8336b340-cc66-4922-aac3-bff0c2a1e524"],
Cell[64710, 1415, 19125, 353, 256, "Output",ExpressionUUID->"d3763a73-d734-46ea-9762-937ff9275e43"]
}, Open  ]],
Cell[83850, 1771, 156, 3, 53, "Text",ExpressionUUID->"ea6f4316-2d41-492d-a413-b5f947e0f702"],
Cell[CellGroupData[{
Cell[84031, 1778, 2344, 65, 157, "Input",ExpressionUUID->"a1967022-e602-436b-aa98-75166c004b97"],
Cell[86378, 1845, 19049, 352, 256, "Output",ExpressionUUID->"5639f67c-e532-4df1-9240-4a388c35706d"]
}, Open  ]],
Cell[105442, 2200, 159, 3, 53, "Text",ExpressionUUID->"8ce81f0e-c2d4-4cd6-ade2-db8b4d0fdc14"],
Cell[CellGroupData[{
Cell[105626, 2207, 2338, 65, 157, "Input",ExpressionUUID->"5dc628aa-c48b-4de9-883e-1cad8e408417"],
Cell[107967, 2274, 19021, 351, 248, "Output",ExpressionUUID->"ec4545b7-fdb8-4713-8679-d66c3c2f8dd5"]
}, Open  ]],
Cell[127003, 2628, 158, 3, 53, "Text",ExpressionUUID->"d1d48429-3efa-47ce-8aa8-0d5823df2bc6"],
Cell[CellGroupData[{
Cell[127186, 2635, 2316, 65, 157, "Input",ExpressionUUID->"f0259726-77b4-41c9-a733-44e45d675552"],
Cell[129505, 2702, 19017, 351, 248, "Output",ExpressionUUID->"8eabeca2-d986-438a-ac6a-a065c5a5d69f"]
}, Open  ]],
Cell[148537, 3056, 158, 3, 53, "Text",ExpressionUUID->"e18a88f3-e850-4812-bdd3-0585bbbd557b"],
Cell[CellGroupData[{
Cell[148720, 3063, 2369, 66, 157, "Input",ExpressionUUID->"35867f40-23ff-43ea-8935-c54317d425d1"],
Cell[151092, 3131, 19025, 351, 256, "Output",ExpressionUUID->"0ff5b2cb-73a0-46b7-8648-cd28b6acbacb"]
}, Open  ]],
Cell[170132, 3485, 159, 3, 53, "Text",ExpressionUUID->"02372833-7e78-4b6a-9113-f227463f5964"],
Cell[CellGroupData[{
Cell[170316, 3492, 2429, 67, 157, "Input",ExpressionUUID->"f755e812-80b9-465e-8395-aa600949727c"],
Cell[172748, 3561, 19032, 351, 251, "Output",ExpressionUUID->"a8850f3a-8e28-49ac-baa8-d5410ed6e938"]
}, Open  ]],
Cell[191795, 3915, 158, 3, 53, "Text",ExpressionUUID->"e5e6f166-ef72-43d0-bdb8-abb26bc1d528"],
Cell[CellGroupData[{
Cell[191978, 3922, 2355, 66, 157, "Input",ExpressionUUID->"94df5fd3-8698-4aa0-85ce-cd8b7064e196"],
Cell[194336, 3990, 19067, 352, 263, "Output",ExpressionUUID->"9bde6f18-d47b-4227-9364-390aad2578a9"]
}, Open  ]],
Cell[213418, 4345, 156, 3, 53, "Text",ExpressionUUID->"8d5610ee-0466-446e-b5e5-b8b94e227c29"],
Cell[CellGroupData[{
Cell[213599, 4352, 2354, 66, 157, "Input",ExpressionUUID->"583b62eb-1acf-4fc4-ae99-d1320861cb0f"],
Cell[215956, 4420, 19379, 358, 261, "Output",ExpressionUUID->"b31e0638-2638-46ed-b3ab-307d0c26a48e"]
}, Open  ]],
Cell[235350, 4781, 156, 3, 53, "Text",ExpressionUUID->"2a9847ec-469d-46aa-805a-e6a11cbc8bd2"],
Cell[CellGroupData[{
Cell[235531, 4788, 2303, 65, 157, "Input",ExpressionUUID->"5c2c5f4d-6e70-45e8-8257-7c333ec1c64e"],
Cell[237837, 4855, 19368, 357, 261, "Output",ExpressionUUID->"c771e40f-2958-46e4-a6c6-1ee23b33148d"]
}, Open  ]],
Cell[257220, 5215, 155, 3, 53, "Text",ExpressionUUID->"0bfde1ef-9843-4674-9f61-7f57cae4ae74"],
Cell[CellGroupData[{
Cell[257400, 5222, 2303, 65, 157, "Input",ExpressionUUID->"ff3199a1-5f59-49fa-ac0f-8421704f1975"],
Cell[259706, 5289, 19244, 355, 268, "Output",ExpressionUUID->"7297f65c-d028-478d-96aa-05e1aed4e734"]
}, Open  ]],
Cell[278965, 5647, 158, 3, 53, "Text",ExpressionUUID->"8bcb66c7-6f9a-46f8-b48b-bdccb4939579"],
Cell[CellGroupData[{
Cell[279148, 5654, 2362, 66, 157, "Input",ExpressionUUID->"13263199-57c1-453e-a82c-f6c5b0b49c38"],
Cell[281513, 5722, 18923, 350, 253, "Output",ExpressionUUID->"57ca1787-fd3a-46f2-a29f-dfe7e778594a"]
}, Open  ]],
Cell[300451, 6075, 157, 3, 53, "Text",ExpressionUUID->"75b70071-0bec-42bd-9249-1464b7b15e51"],
Cell[CellGroupData[{
Cell[300633, 6082, 2362, 66, 157, "Input",ExpressionUUID->"92d33181-7fbe-4621-9f65-c928acf1fda5"],
Cell[302998, 6150, 19131, 354, 268, "Output",ExpressionUUID->"64e84c5f-4215-4889-b217-bf2f9baa7d76"]
}, Open  ]],
Cell[322144, 6507, 157, 3, 53, "Text",ExpressionUUID->"45f69281-4d4f-41d0-a10d-ccee783af856"],
Cell[CellGroupData[{
Cell[322326, 6514, 2308, 65, 157, "Input",ExpressionUUID->"b69f62e7-43be-454f-b0c4-8b86a95b3385"],
Cell[324637, 6581, 19279, 356, 268, "Output",ExpressionUUID->"ef82f232-8287-4b0d-913c-8d1559deffa3"]
}, Open  ]],
Cell[343931, 6940, 158, 3, 53, "Text",ExpressionUUID->"540092ee-8d88-447d-acc5-14674b6564b8"],
Cell[CellGroupData[{
Cell[344114, 6947, 2387, 66, 157, "Input",ExpressionUUID->"dbde7bd1-8bbb-410f-a460-3a5884347e84"],
Cell[346504, 7015, 19197, 354, 261, "Output",ExpressionUUID->"2649d287-48d8-418a-b976-42f00b6433e7"]
}, Open  ]],
Cell[365716, 7372, 332, 9, 99, "Text",ExpressionUUID->"e2ef93c3-3c7e-46c6-bc6f-9ecf6b31a0a6"],
Cell[366051, 7383, 137, 1, 30, "Input",ExpressionUUID->"5788c09e-2161-4143-80b7-726c1a84a1ad"],
Cell[366191, 7386, 158, 3, 53, "Text",ExpressionUUID->"6abfd1e5-fd95-4e55-b290-6768286bdbcc"],
Cell[366352, 7391, 187, 2, 30, "Input",ExpressionUUID->"acedb428-07c2-45e1-b31b-cceb4e88748c"],
Cell[366542, 7395, 162, 3, 53, "Text",ExpressionUUID->"eeb62851-74b2-4357-8e88-05aba2cd0cea"],
Cell[366707, 7400, 186, 2, 30, "Input",ExpressionUUID->"b50a7778-a455-487c-8cd6-fa672d34f214"],
Cell[366896, 7404, 157, 3, 53, "Text",ExpressionUUID->"daa75b68-844a-42c2-82e1-10e255e747e5"],
Cell[367056, 7409, 196, 2, 30, "Input",ExpressionUUID->"8c8335f8-a4c8-4228-b104-105d58d20e9d"],
Cell[367255, 7413, 156, 3, 53, "Text",ExpressionUUID->"002ee8b8-611e-429e-ba91-b8502d8c9a81"],
Cell[367414, 7418, 128, 1, 30, "Input",ExpressionUUID->"e41316ec-09bf-4f61-b9b2-9acf28935601"],
Cell[367545, 7421, 156, 3, 53, "Text",ExpressionUUID->"fdfa9363-0aa9-4b56-9c0a-cfe93a60d640"],
Cell[367704, 7426, 127, 1, 30, "Input",ExpressionUUID->"8ce562a2-f580-4511-855d-3482bd632042"],
Cell[367834, 7429, 155, 3, 53, "Text",ExpressionUUID->"8ab7754e-c380-4313-b28e-17ec4bb01811"],
Cell[367992, 7434, 127, 1, 30, "Input",ExpressionUUID->"40dd5dd5-8f48-4b66-a8c0-cfceca6332de"],
Cell[368122, 7437, 543, 14, 53, "Text",ExpressionUUID->"b0f96742-cc9c-41d8-8f4c-7284b98f5238"],
Cell[CellGroupData[{
Cell[368690, 7455, 2550, 71, 157, "Input",ExpressionUUID->"94c5c14f-977a-43e1-85e3-79e4e6b79fdb"],
Cell[371243, 7528, 11115, 221, 243, "Output",ExpressionUUID->"784f8435-32e1-45ec-b51f-d9d523f5d22d"]
}, Open  ]],
Cell[382373, 7752, 588, 14, 53, "Text",ExpressionUUID->"569f5085-8dd3-47ab-bf73-afd57b66de57"],
Cell[CellGroupData[{
Cell[382986, 7770, 2571, 71, 136, "Input",ExpressionUUID->"b3daec87-d277-41c6-b4e1-c9adb8398cde"],
Cell[385560, 7843, 11304, 225, 285, "Output",ExpressionUUID->"0ea78c58-d4b9-44b2-a77d-78604f9a2153"]
}, Open  ]]
}
]
*)

